@@ -18,8 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef _PLAYERNETMESSAGE_HPP
 #define _PLAYERNETMESSAGE_HPP
 
-#include "NetPacket.hpp"
-
+#include "NetMessage.hpp"
 
 enum { _net_message_id_player_connect_id,
        _net_message_id_player_sync_state,
@@ -62,16 +61,42 @@ public:
 
 class PlayerScoreUpdate : public NetMessage
 {
+private:
+    uint16_t kill_by_player_index;
+    uint16_t kill_on_player_index;
 public:
-    unsigned short kill_by_player_index;
-    unsigned short kill_on_player_index;
-    unsigned char  unit_type;
+    uint8_t  unit_type;
 
     PlayerScoreUpdate()
     {
         message_class = _net_message_class_player;
         message_id = _net_message_id_player_score_update;
     }
+
+    void set(uint16_t kill_by_index, uint16_t kill_on_index, uint8_t unit_type)
+    {
+        kill_by_player_index = htol16(kill_by_index);
+        kill_on_player_index = htol16(kill_on_index);
+        this->unit_type = unit_type;
+    }
+
+    void setKillByPlayerIndex(uint16_t kill_by_index)
+    {
+        kill_by_player_index = htol16(kill_by_index);
+    }
+    uint16_t getKillByPlayerIndex() const
+    {
+        return ltoh16(kill_by_player_index);
+    }
+
+    void setKillOnPlayerIndex(uint16_t kill_on_index)
+    {
+        kill_on_player_index = htol16(kill_on_index);
+    }
+    uint16_t getKillOnPlayerIndex() const
+    {
+        return ltoh16(kill_on_player_index);
+    }
 }
 __attribute__((packed));
 
@@ -82,26 +107,44 @@ enum { _player_make_alliance,
 
 class PlayerAllianceRequest : public NetMessage
 {
+private:
+    uint16_t allie_by_player_index;
+    uint16_t allie_with_player_index;
 public:
-    unsigned short allie_by_player_index;
-    unsigned short allie_with_player_index;
-    unsigned char  alliance_request_type;
+    uint8_t  alliance_request_type;
 
     PlayerAllianceRequest()
     {
         message_class = _net_message_class_player;
         message_id = _net_message_id_player_alliance_request;
     }
+
+    void set(uint16_t allie_by_player_index, uint16_t allie_with_player_index,
+            uint8_t alliance_request_type)
+    {
+        this->allie_by_player_index = htol16(allie_by_player_index);
+        this->allie_with_player_index = htol16(allie_with_player_index);
+        this->alliance_request_type = alliance_request_type;
+    }
+    uint16_t getAllieByPlayerIndex() const
+    {
+        return ltoh16(allie_by_player_index);
+    }
+    uint16_t getAllieWithPlayerIndex() const
+    {
+        return ltoh16(allie_with_player_index);
+    }
 }
 __attribute__((packed));
 
 
 class PlayerAllianceUpdate : public NetMessage
 {
+private:
+    uint16_t allie_by_player_index;
+    uint16_t allie_with_player_index;
 public:
-    unsigned short allie_by_player_index;
-    unsigned short allie_with_player_index;
-    unsigned char  alliance_update_type;
+    uint8_t  alliance_update_type;
 
     PlayerAllianceUpdate()
     {
@@ -109,12 +152,22 @@ public:
         message_id = _net_message_id_player_alliance_update;
     }
 
-    void set( unsigned short by_player_index, unsigned short with_player_index, unsigned char update_type )
+    void set(uint16_t by_player_index, uint16_t with_player_index,
+            uint8_t update_type )
     {
-        allie_by_player_index = by_player_index;
-        allie_with_player_index = with_player_index;
+        allie_by_player_index = htol16(by_player_index);
+        allie_with_player_index = htol16(with_player_index);
         alliance_update_type = update_type;
     }
+
+    uint16_t getAllieByPlayerIndex() const
+    {
+        return ltoh16(allie_by_player_index);
+    }
+    uint16_t getAllieWithPlayerIndex() const
+    {
+        return ltoh16(allie_with_player_index);
+    }
 }
 __attribute__((packed));
 
