@@ -26,6 +26,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "PowerUpInterface.hpp"
 #include "MapInterface.hpp"
 #include "Server.hpp"
+#include "NetworkServer.hpp"
 #include "GameManager.hpp"
 #include "GameConfig.hpp"
 
@@ -59,14 +60,16 @@ UnitSync*           ServerConnectDaemon::connect_unit_sync = 0;
 #define _SERVER_CONNECT_RETRY_LIMIT   (5)
 
 
-void ServerConnectDaemon::initialize( unsigned long max_players )
+void ServerConnectDaemon::initialize(unsigned long max_players)
 {
+    (void) max_players;
     time_out_timer.changePeriod( _SERVER_CONNECT_TIME_OUT_TIME );
     connect_unit_sync = 0;
 }
 
 void ServerConnectDaemon::startConnectDaemon( unsigned long max_players )
 {
+    (void) max_players;
     time_out_timer.changePeriod( _SERVER_CONNECT_TIME_OUT_TIME );
 }
 
@@ -77,26 +80,7 @@ void ServerConnectDaemon::shutdownConnectDaemon()
     ConnectMesgNetPanzerServerDisconnect server_disconnect;
 
     SERVER->sendMessage( &server_disconnect,
-                         sizeof(ConnectMesgNetPanzerServerDisconnect),
-                         0 );
-}
-
-void ServerConnectDaemon::startConnectionProcess( PlayerID new_player_id )
-{
-    ConnectQueueElement connect_request;
-
-
-    if ( !inConnectQueue( new_player_id) ) {
-        connect_request.new_player_id  = new_player_id;
-        connect_request.connect_status = _connect_status_waiting;
-
-        connect_queue.push_back(connect_request);
-
-        ClientConnectJoinRequestAck link_ack;
-
-        SERVER->sendMessage( new_player_id, &link_ack,
-                             sizeof(ClientConnectJoinRequestAck), 0);
-    }
+                         sizeof(ConnectMesgNetPanzerServerDisconnect));
 }
 
 bool ServerConnectDaemon::inConnectQueue( PlayerID &new_player_id )
@@ -128,94 +112,87 @@ void ServerConnectDaemon::updateQueuedClients()
         const ConnectQueueElement& connect_request = *i;
       
         ConnectProcessUpdate process_update;
-        process_update.queue_position = queue_position;
+        process_update.setQueuePosition(queue_position);
 
         SERVER->sendMessage( connect_request.new_player_id, &process_update,
-                             sizeof(ConnectProcessUpdate), 0);
+                             sizeof(ConnectProcessUpdate));
 
         queue_position++;
     }
 
 }
 
-void ServerConnectDaemon::netMessageClientDisconnect( NetMessage *message )
+void ServerConnectDaemon::netMessageClientDisconnect(const NetMessage *message)
 {
     ConnectMesgNetPanzerClientDisconnect *client_disconnect;
 
     client_disconnect = (ConnectMesgNetPanzerClientDisconnect *) message;
 
-    if(client_disconnect->client_id >= PlayerInterface::getMaxPlayers()) {
+    if(client_disconnect->getPlayerID() >= PlayerInterface::getMaxPlayers()) {
         LOGGER.warning("Received malformed disconnection message.");
         return;
     }
     
     startDisconnectionProcess(
-            PlayerInterface::getPlayerID(client_disconnect->client_id) );
+            PlayerInterface::getPlayerID(client_disconnect->getPlayerID()) );
 }
 
-void ServerConnectDaemon::netMessageClientJoinRequest( NetMessage *message )
+void ServerConnectDaemon::netPacketClientJoinRequest(const NetPacket* packet)
 {
-    ClientConnectJoinRequest *join_request_mesg;
+    const ClientConnectJoinRequest* join_request_mesg
+        = (const ClientConnectJoinRequest *) packet->getNetMessage();
     ClientConnectJoinRequestAck join_request_ack;
     PlayerID new_player_id;
 
-    join_request_mesg = (ClientConnectJoinRequest *) message;
+    new_player_id = PlayerID(0, packet->fromID);
 
-    new_player_id = PlayerID(0, join_request_mesg->client_transport_id );
-
-    if( (strcmp(join_request_mesg->code_word, _NETPANZER_CODEWORD) != 0) ||
-            (join_request_mesg->protocol_version == _NETPANZER_PROTOCOL_VERSION)
-      ) {
-        join_request_ack.result_code = _join_request_result_success;
+    if(join_request_mesg->getProtocolVersion() == NETPANZER_PROTOCOL_VERSION) {
+        join_request_ack.setResultCode(_join_request_result_success);
     } else {
-        join_request_ack.result_code = _join_request_result_invalid_protocol;
+        join_request_ack.setResultCode(_join_request_result_invalid_protocol);
     }
 
-    join_request_ack.server_protocol_version = _NETPANZER_PROTOCOL_VERSION;
-
-    if( join_request_ack.result_code == _join_request_result_success ) {
+    join_request_ack.setServerProtocolVersion(NETPANZER_PROTOCOL_VERSION);
 
+    if( join_request_ack.getResultCode() == _join_request_result_success ) {
         ConnectQueueElement connect_request;
 
-
         if ( !inConnectQueue( new_player_id) ) {
             connect_request.new_player_id  = new_player_id;
             connect_request.connect_status = _connect_status_waiting;
 
             if (connect_queue.size() > 25) {
-                join_request_ack.result_code = _join_request_result_server_busy;
+                join_request_ack.setResultCode(_join_request_result_server_busy);
             } else {
                 connect_queue.push_back(connect_request);
             }
-
         }
-
     }
 
-    SERVER->sendMessage( new_player_id, &join_request_ack,
-                         sizeof(ClientConnectJoinRequestAck), 0);
-
+    SERVER->sendMessage(packet->fromID, &join_request_ack,
+                         sizeof(ClientConnectJoinRequestAck));
 }
 
-void ServerConnectDaemon::processNetMessage( NetMessage *message )
+void ServerConnectDaemon::processNetPacket(const NetPacket* packet)
 {
-    switch (message->message_id) {
-    case _net_message_id_connect_netPanzer_client_disconnect :
-        netMessageClientDisconnect( message );
-        break;
+    const NetMessage* message = packet->getNetMessage();
 
-    case _net_message_id_connect_join_game_request :
-        netMessageClientJoinRequest( message );
-        break;
+    switch(message->message_id) {
+        case _net_message_id_connect_netPanzer_client_disconnect:
+            netMessageClientDisconnect(message);
+            break;
 
-    default :
-        connectFsm( message );
-        break;
-    } // ** switch
+        case _net_message_id_connect_join_game_request:
+            netPacketClientJoinRequest(packet);
+            break;
 
+        default :
+            connectFsm(message);
+            break;
+    }
 }
 
-void ServerConnectDaemon::sendConnectionAlert( PlayerID &player_id, int alert_enum )
+void ServerConnectDaemon::sendConnectionAlert(PlayerID &player_id, int alert_enum)
 {
     SystemConnectAlert connect_alert;
     PlayerState *player_state = 0;
@@ -226,14 +203,14 @@ void ServerConnectDaemon::sendConnectionAlert( PlayerID &player_id, int alert_en
     switch( alert_enum ) {
     case _connect_alert_mesg_connect : {
             connect_alert.set( player_id, _connect_alert_mesg_connect );
-            ConsoleInterface::postMessage( "%s has joined the game.",
+            ConsoleInterface::postMessage( "'%s' has joined the game.",
                     player_state->getName().c_str() );
         }
         break;
 
     case _connect_alert_mesg_disconnect : {
             connect_alert.set( player_id, _connect_alert_mesg_disconnect );
-            ConsoleInterface::postMessage( "%s has left the game.",
+            ConsoleInterface::postMessage( "'%s' has left the game.",
                     player_state->getName().c_str() );
         }
         break;
@@ -241,7 +218,9 @@ void ServerConnectDaemon::sendConnectionAlert( PlayerID &player_id, int alert_en
     case _connect_alert_mesg_client_drop : {
             connect_alert.set( player_id, _connect_alert_mesg_client_drop );
             ConsoleInterface::postMessage(
-                    "Connection to %s has been unexpectedly broken.",
+                    "Connection to '%s' has been unexpectedly broken.",
+                    player_state->getName().c_str() );
+            ConsoleInterface::postMessage( "'%s' has left the game.",
                     player_state->getName().c_str() );
         }
         break;
@@ -250,7 +229,7 @@ void ServerConnectDaemon::sendConnectionAlert( PlayerID &player_id, int alert_en
         assert(0);
     } // ** switch
 
-    SERVER->sendMessage( &connect_alert, sizeof(SystemConnectAlert), 0 );
+    SERVER->sendMessage( &connect_alert, sizeof(SystemConnectAlert));
 }
 
 void ServerConnectDaemon::resetConnectFsm()
@@ -273,15 +252,8 @@ bool ServerConnectDaemon::connectStateIdle()
 
         ClientConnectStartConnect start_connect;
 
-        int send_ret_val;
-
-        send_ret_val  = SERVER->sendMessage( connect_player_id, &start_connect,
-                                             sizeof(ClientConnectStartConnect), 0);
-
-        if( send_ret_val != _network_ok ) {
-            resetConnectFsm();
-            return( true );
-        }
+        SERVER->sendMessage(connect_player_id, &start_connect,
+                                            sizeof(ClientConnectStartConnect));
 
         time_out_timer.changePeriod( _SERVER_CONNECT_TIME_OUT_TIME );
         time_out_timer.reset();
@@ -290,36 +262,37 @@ bool ServerConnectDaemon::connectStateIdle()
         updateQueuedClients();
     }
 
-    return( true );
+    return true;
 }
 
 
-bool ServerConnectDaemon::connectStateWaitForConnectRequest( NetMessage *message )
+bool ServerConnectDaemon::connectStateWaitForConnectRequest(
+        const NetMessage* message)
 {
-    if ( message != 0 ) {
+    if (message != 0) {
         if ( message->message_id == _net_message_id_client_connect_request ) {
             connection_state = _connect_state_attempt_player_alloc;
-            return( false );
+            return false;
         } else {
             if ( time_out_timer.count() ) {
                 resetConnectFsm();
-                return( true );
+                return true;
             }
 
-            return( true );
+            return true;
         }
 
     } // ** if ( message != 0 )
     else {
         if ( time_out_timer.count() ) {
             resetConnectFsm();
-            return( true );
+            return true;
         }
 
-        return( true );
+        return true;
     }
 
-    return( true );
+    return true;
 }
 
 bool ServerConnectDaemon::connectStateAttemptPlayerAlloc()
@@ -327,40 +300,29 @@ bool ServerConnectDaemon::connectStateAttemptPlayerAlloc()
     ClientConnectResult connect_result;
     connect_player_state = PlayerInterface::allocateNewPlayer();
 
-    int send_ret_val;
-
     if ( connect_player_state == 0 ) {
         connect_result.result_code = _connect_result_server_full;
 
-        send_ret_val = SERVER->sendMessage( connect_player_id, &connect_result,
-                                            sizeof(ClientConnectResult), 0);
-
+        SERVER->sendMessage( connect_player_id, &connect_result,
+                                            sizeof(ClientConnectResult));
         resetConnectFsm();
-        return( true );
+        return true;
     } else {
         connect_result.result_code = _connect_result_success;
 
-        send_ret_val = SERVER->sendMessage( connect_player_id, &connect_result,
-                                            sizeof(ClientConnectResult), 0 );
-
-        if( send_ret_val != _network_ok ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
-            return( true );
-        }
-
+        SERVER->sendMessage( connect_player_id, &connect_result,
+                                            sizeof(ClientConnectResult));
 
         time_out_timer.reset();
         connection_state = _connect_state_wait_for_client_settings;
-        return( true );
+        return true;
     }
 
 }
 
-bool ServerConnectDaemon::connectStateWaitForClientSettings( NetMessage *message )
+bool ServerConnectDaemon::connectStateWaitForClientSettings(
+        const NetMessage* message )
 {
-    int send_ret_val;
-
     if ( message != 0 ) {
         if ( message->message_id == _net_message_id_connect_client_settings ) {
             ConnectClientSettings *client_setting;
@@ -368,170 +330,120 @@ bool ServerConnectDaemon::connectStateWaitForClientSettings( NetMessage *message
             client_setting = (ConnectClientSettings *) message;
             connect_player_state->setName( client_setting->player_name );
             connect_player_state->unit_config.setUnitColor( client_setting->unit_color );
-            connect_player_state->setFlag( client_setting->player_flag );
+            connect_player_state->setFlag( client_setting->getPlayerFlag() );
 
             connect_player_state->setID( connect_player_id.getNetworkID() );
             connect_player_state->setStatus( _player_state_connecting );
             connect_player_id = connect_player_state->getPlayerID();
 
             // ** send server game setting map, units, player, etc.
-            ConnectMesgServerGameSettings server_game_setup;
-            GameManager::getServerGameSetup( &server_game_setup );
-
-            send_ret_val = SERVER->sendMessage( connect_player_id, &server_game_setup,
-                                                sizeof(ConnectMesgServerGameSettings), 0);
-
-            if( send_ret_val != _network_ok ) {
-                connect_player_state->setStatus( _player_state_free );
-                resetConnectFsm();
-                return( true );
-            }
+            ConnectMesgServerGameSettings* server_game_setup
+                = GameManager::getServerGameSetup();
+            SERVER->sendMessage(connect_player_id,
+                    server_game_setup, sizeof(ConnectMesgServerGameSettings));
+            delete server_game_setup;
 
             time_out_timer.reset();
             connection_state = _connect_state_wait_for_client_game_setup_ack;
-            return( true );
+            return true;
         } else {
             if ( time_out_timer.count() ) {
                 connect_player_state->setStatus( _player_state_free );
                 resetConnectFsm();
-                return( true );
+                return true;
             }
 
-            return( true);
+            return true;
         }
-    } // ** if ( message != 0 )
-    else {
+    } else {
         if ( time_out_timer.count() ) {
             connect_player_state->setStatus( _player_state_free );
             resetConnectFsm();
-            return( true );
+            return true;
         }
 
-        return( true );
+        return true;
     }
 
-    return( true );
+    return true;
 }
 
-bool ServerConnectDaemon::connectStateWaitForClientGameSetupAck( NetMessage *message )
+bool ServerConnectDaemon::connectStateWaitForClientGameSetupAck(
+        const NetMessage* message )
 {
-    int send_ret_val;
-
     if ( message != 0 ) {
         if ( message->message_id == _net_message_id_connect_client_game_setup_ack ) {
             PlayerConnectID player_connect_mesg
                 (connect_player_state->getNetworkPlayerState());
 
-            send_ret_val = SERVER->sendMessage(connect_player_id, &player_connect_mesg, sizeof(PlayerConnectID), 0 );
-
-            if( send_ret_val != _network_ok ) {
-                connect_player_state->setStatus( _player_state_free );
-                resetConnectFsm();
-                return( true );
-            }
-
+            SERVER->sendMessage(connect_player_id, &player_connect_mesg,
+                    sizeof(PlayerConnectID));
             PlayerInterface::startPlayerStateSync( connect_player_id );
 
             ConnectProcessStateMessage state_mesg;
-            state_mesg.message_enum = _connect_state_message_sync_player_info;
-            send_ret_val = SERVER->sendMessage( connect_player_id, &state_mesg,
-                                                sizeof(ConnectProcessStateMessage), 0);
-
-            if( send_ret_val != _network_ok ) {
-                connect_player_state->setStatus( _player_state_free );
-                resetConnectFsm();
-                return( true );
-            }
-
+            state_mesg.setMessageEnum(_connect_state_message_sync_player_info);
+            SERVER->sendMessage(connect_player_id, &state_mesg,
+                    sizeof(ConnectProcessStateMessage));
             connection_state = _connect_state_player_state_sync;
-
-            SERVER->activateKeepAlive( connect_player_id );
         } else
             if ( message->message_id == _net_message_id_connect_client_game_setup_ping ) {
                 time_out_timer.reset();
-                return( true );
+                return true;
             } else {
                 if ( time_out_timer.count() ) {
                     connect_player_state->setStatus( _player_state_free );
                     resetConnectFsm();
-                    return( true );
+                    return true;
                 }
 
-                return( true );
+                return true;
             }
 
     } else {
         if ( time_out_timer.count() ) {
             connect_player_state->setStatus( _player_state_free );
             resetConnectFsm();
-            return( true );
+            return true;
         }
 
-        return( true );
+        return true;
     }
 
-    return( true );
+    return true;
 }
 
 bool ServerConnectDaemon::connectStatePlayerStateSync()
 {
     ConnectProcessStateMessage state_mesg;
-    int send_ret_val;
     int percent_complete;
 
-    if ( PlayerInterface::syncPlayerState( &send_ret_val, &percent_complete ) == true ) {
-        if( send_ret_val != _network_ok ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
-            return( true );
-        }
-
-        state_mesg.message_enum = _connect_state_message_sync_player_info_percent;
-        state_mesg.percent_complete = percent_complete;
-        send_ret_val = SERVER->sendMessage( connect_player_id, &state_mesg, sizeof(ConnectProcessStateMessage), 0);
-
-        if( send_ret_val != _network_ok ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
-            return( true );
-        }
-
+    if (PlayerInterface::syncPlayerState( &percent_complete ) == true ) {
+        state_mesg.setMessageEnum(_connect_state_message_sync_player_info_percent);
+        state_mesg.setPercentComplete(percent_complete);
+        SERVER->sendMessage(connect_player_id, &state_mesg,
+                sizeof(ConnectProcessStateMessage));
         delete connect_unit_sync;
         connect_unit_sync = new UnitSync();
 
-        state_mesg.message_enum = _connect_state_message_sync_units;
-        send_ret_val = SERVER->sendMessage( connect_player_id, &state_mesg, sizeof(ConnectProcessStateMessage), 0 );
-
-        if( send_ret_val != _network_ok ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
-            return( true );
-        }
-
+        state_mesg.setMessageEnum(_connect_state_message_sync_units);
+        SERVER->sendMessage( connect_player_id, &state_mesg,
+                sizeof(ConnectProcessStateMessage));
         SERVER->addClientToSendList( connect_player_id );
 
         PlayerStateSync player_state_update
             (connect_player_state->getNetworkPlayerState());
 
-        SERVER->sendMessage( &player_state_update, sizeof(PlayerStateSync), 0 );
-
-
+        SERVER->sendMessage(&player_state_update, sizeof(PlayerStateSync));
         connection_state = _connect_state_unit_sync;
-        return( true );
-    } else
-        if ( percent_complete > 0 ) {
-            state_mesg.message_enum = _connect_state_message_sync_player_info_percent;
-            state_mesg.percent_complete = percent_complete;
-            send_ret_val = SERVER->sendMessage( connect_player_id, &state_mesg, sizeof(ConnectProcessStateMessage), 0 );
+        return true;
+    } else if ( percent_complete > 0 ) {
+        state_mesg.setMessageEnum(_connect_state_message_sync_player_info_percent);
+        state_mesg.setPercentComplete(percent_complete);
+        SERVER->sendMessage(connect_player_id, &state_mesg,
+                sizeof(ConnectProcessStateMessage));
+    }
 
-            if( send_ret_val != _network_ok ) {
-                connect_player_state->setStatus( _player_state_free );
-                resetConnectFsm();
-                return( true );
-            }
-        }
-
-    return( true );
+    return true;
 }
 
 bool ServerConnectDaemon::connectStateUnitSync()
@@ -541,36 +453,22 @@ bool ServerConnectDaemon::connectStateUnitSync()
 
     // send a unit
     if(connect_unit_sync->sendNextUnit(connect_player_id)) {
-        state_mesg.message_enum = _connect_state_message_sync_units_percent;
-        state_mesg.percent_complete = percent_complete;
-        int ret = SERVER->sendMessage(connect_player_id, &state_mesg,
-                sizeof(ConnectProcessStateMessage), 0);
-        
-        if(ret != _network_ok ) {
-            resetConnectFsm();
-        }
-
+        state_mesg.setMessageEnum(_connect_state_message_sync_units_percent);
+        state_mesg.setPercentComplete(percent_complete);
+        SERVER->sendMessage(connect_player_id, &state_mesg,
+                sizeof(ConnectProcessStateMessage));
         return true;
     }
 
     // Sending finished
-    state_mesg.message_enum = _connect_state_message_sync_units_percent;
-    state_mesg.percent_complete = percent_complete;
-    int ret = SERVER->sendMessage( connect_player_id, &state_mesg,
-            sizeof(ConnectProcessStateMessage), 0 );
-
-    if(ret != _network_ok) {
-        resetConnectFsm();
-        return true;
-    }
+    state_mesg.setMessageEnum(_connect_state_message_sync_units_percent);
+    state_mesg.setPercentComplete(percent_complete);
+    SERVER->sendMessage( connect_player_id, &state_mesg,
+            sizeof(ConnectProcessStateMessage));
 
     UnitSyncIntegrityCheck unit_integrity_check_mesg;
-    ret = SERVER->sendMessage( connect_player_id, &unit_integrity_check_mesg, sizeof(UnitSyncIntegrityCheck), 0 );
-    
-    if(ret != _network_ok ) {
-        resetConnectFsm();
-        return true;
-    }
+    SERVER->sendMessage( connect_player_id, &unit_integrity_check_mesg,
+            sizeof(UnitSyncIntegrityCheck));
 
     ObjectiveInterface::syncObjectives( connect_player_id );
 
@@ -583,23 +481,18 @@ bool ServerConnectDaemon::connectStateUnitSync()
     PlayerStateSync player_state_update
         (connect_player_state->getNetworkPlayerState());
 
-    SERVER->sendMessage( &player_state_update, sizeof(PlayerStateSync), 0 );
-
-    state_mesg.message_enum = _connect_state_sync_complete;
-    ret = SERVER->sendMessage( connect_player_id, &state_mesg, sizeof(ConnectProcessStateMessage), 0 );
-
-    if(ret != _network_ok ) {
-        resetConnectFsm();
-        return true;
-    }
+    SERVER->sendMessage( &player_state_update, sizeof(PlayerStateSync));
 
+    state_mesg.setMessageEnum(_connect_state_sync_complete);
+    SERVER->sendMessage( connect_player_id, &state_mesg,
+            sizeof(ConnectProcessStateMessage));
     sendConnectionAlert( connect_player_id, _connect_alert_mesg_connect );
 
     connection_state = _connect_state_idle;
     return true;
 }
 
-void ServerConnectDaemon::connectFsm( NetMessage *message )
+void ServerConnectDaemon::connectFsm(const NetMessage* message)
 {
     bool end_cycle = false;
 
@@ -676,10 +569,9 @@ void ServerConnectDaemon::connectFsm( NetMessage *message )
     } while( end_cycle == false );
 
 
-} // ** connectFsm( NetMessage *message )
+}
 
-
-void ServerConnectDaemon::connectProcess( NetMessage *message)
+void ServerConnectDaemon::connectProcess(const NetMessage* message)
 {
     connectFsm( message );
 }
@@ -691,17 +583,14 @@ void ServerConnectDaemon::connectProcess()
 
 bool ServerConnectDaemon::disconnectClient( PlayerID player_id )
 {
-    SERVER->shutdownClientTransport( player_id );
+    SERVER->shutdownClientTransport(player_id.getNetworkID());
 
-    if ( SERVER->removeClientFromSendList( player_id ) == true ) {
-        ObjectiveInterface::disownPlayerObjectives( player_id );
-        UnitInterface::destroyPlayerUnits( player_id );
-        PlayerInterface::disconnectPlayerCleanup( player_id );
+    SERVER->removeClientFromSendList(player_id);
+    ObjectiveInterface::disownPlayerObjectives( player_id );
+    UnitInterface::destroyPlayerUnits(player_id.getIndex());
+    PlayerInterface::disconnectPlayerCleanup( player_id );
 
-        return( true );
-    }
-
-    return( false );
+    return true;
 }
 
 
@@ -737,8 +626,8 @@ bool ServerConnectDaemon::getConnectLockStatus()
 bool ServerConnectDaemon::isConnecting()
 {
     if( connection_state == _connect_state_idle ) {
-        return ( false );
+        return false;
     }
 
-    return( true );
+    return true;
 }
