@@ -20,6 +20,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "UnitInterface.hpp"
 #include "UnitList.hpp"
+#include "UnitBase.hpp"
 
 class UnitSync
 {
@@ -36,9 +37,8 @@ public:
     bool sendNextUnit(PlayerID playerid);
 
 private:
-    size_t playerid;
-    UnitList* unitlist;
-    UnitList::AsyncIterator iter;
+    size_t count;
+    UnitID unitid;
 };
 
 #endif
