@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define _UNITMESSAGE_HPP
 
 #include <stdint.h>
-#include "UnitID.hpp"
+#include "UnitBase.hpp"
 
 enum { _umesg_flag_unique          = 0x01,
        _umesg_flag_broadcast       = 0x02,
@@ -36,38 +36,51 @@ enum { _umesg_flag_unique          = 0x01,
 
 class UnitMessage
 {
+private:
+    uint16_t unit_id;
 public:
-    UnitID unit_id;
     uint8_t message_id;
     uint8_t message_flags;
 
 public:
-
     UnitMessage()
-    {}
-    UnitMessage( UnitID unit_id, unsigned char flags );
-    UnitMessage( unsigned char flags );
-
-    inline void setHeader( UnitID unit_id, unsigned char flags )
     {
-        UnitMessage::unit_id = unit_id;
+        this->unit_id = 0xBADBADBA;
+        message_id = 0;
+        message_flags = 0;
+    }
+
+    UnitMessage(UnitID unit_Id, unsigned char flags)
+    {
+        setHeader(unit_Id, flags);
+    }
+
+    UnitID getUnitID() const
+    {
+        return ltoh16(unit_id);
+    }
+
+    void setHeader(UnitID unit_id, unsigned char flags )
+    {
+        this->unit_id = htol16(unit_id);
         message_flags = flags;
     }
 
-    inline void setHeader( unsigned char flags )
+#if 0
+    void setHeader(unsigned char flags)
     {
         message_flags = flags;
     }
+#endif
 
-    inline bool isFlagged( unsigned char flags )
+    bool isFlagged(unsigned char flags) const
     {
         if ( (flags & message_flags) == flags )
-            return( true );
+            return true;
 
-        return( false );
+        return false;
     }
-}
-__attribute__((packed));
+} __attribute__((packed));
 
 #ifdef MSVC
 #pragma pack()
