@@ -19,7 +19,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define _UNITMESSAGETYPES_HPP
 
 #include "UnitMessage.hpp"
-#include "UnitID.hpp"
 
 enum { _umesg_ai_command,
        _umesg_weapon_hit,
@@ -41,85 +40,160 @@ class UMesgAICommand : public UnitMessage
 {
 public:
     uint8_t command;
-    iXY goal_loc;
-    UnitID target_id;
+private:
+    int32_t goal_loc_x;
+    int32_t goal_loc_y;
+    uint16_t target_id;
+public:
     uint8_t manual_move_orientation;
-    iXY target_loc;
-
+private:
+    int32_t target_loc_x;
+    int32_t target_loc_y;
+public:
     UMesgAICommand()
     {
+        command = 0;
+        goal_loc_x = goal_loc_y = 0;
+        target_id = 0;
+        manual_move_orientation = 0;
+        target_loc_x = target_loc_y = 0;
     }
 
-    UMesgAICommand( UnitID unit_id, unsigned char flags )
+    UMesgAICommand(UnitID unit_id, unsigned char flags)
             : UnitMessage(unit_id, flags )
     {
+        command = 0;
+        goal_loc_x = goal_loc_y = 0;
+        target_id = 0;
+        manual_move_orientation = 0;
+        target_loc_x = target_loc_y = 0;
     }
 
-    inline void setMoveToLoc( iXY &goal )
+    void setMoveToLoc(const iXY& goal)
     {
         message_id = _umesg_ai_command;
         command = _command_move_to_loc;
-        goal_loc = goal;
+        goal_loc_x = htol32(goal.x);
+        goal_loc_y = htol32(goal.y);
         manual_move_orientation = 0;
     }
 
-    inline void setTargetUnit( UnitID &target )
+    void setTargetUnit(UnitID target)
     {
         message_id = _umesg_ai_command;
         command = _command_attack_unit;
-        target_id = target;
+        target_id = htol16(target);
         manual_move_orientation = 0;
     }
 
-    inline void setStartManualMove( unsigned char orientation )
+    void setStartManualMove(unsigned char orientation)
     {
         message_id = _umesg_ai_command;
         command = _command_start_manual_move;
         manual_move_orientation = orientation;
     }
 
-    inline void setStopManualMove( void )
+    void setStopManualMove()
     {
         message_id = _umesg_ai_command;
         command = _command_stop_manual_move;
         manual_move_orientation = 0;
     }
 
-    inline void setManualFire( iXY &target )
+    void setManualFire(const iXY& target)
     {
         message_id = _umesg_ai_command;
         command = _command_manual_fire;
-        target_loc = target;
+        target_loc_x = htol32(target.x);
+        target_loc_y = htol32(target.y);
         manual_move_orientation = 0;
     }
+
+    iXY getGoalLoc() const
+    {
+        return iXY(ltoh32(goal_loc_x), ltoh32(goal_loc_y));
+    }
+
+    UnitID getTargetUnitID() const
+    {
+        return ltoh16(target_id);
+    }
+
+    iXY getTargetLoc() const
+    {
+        return iXY(ltoh32(target_loc_x), ltoh32(target_loc_y));
+    }
 }
 __attribute__((packed));
 
 class UMesgWeaponHit : public UnitMessage
 {
+private:
+    uint16_t owner_id;
+    int32_t  hit_location_x;
+    int32_t  hit_location_y;
+    uint16_t damage_factor;
+        
 public:
-    UnitID owner_id;
-    iXY hit_location;
-    unsigned short damage_factor;
+    void setOwnerUnitID(UnitID id)
+    {
+        owner_id = htol16(id);
+    }
 
-}
-__attribute__((packed));
+    UnitID getOwnerUnitID() const
+    {
+        return ltoh16(owner_id);
+    }
+
+    void setHitLocation(const iXY& point)
+    {
+        hit_location_x = htol32(point.x);
+        hit_location_y = htol32(point.y);
+    }
+
+    iXY getHitLocation() const
+    {
+        return iXY(ltoh32(hit_location_x), ltoh32(hit_location_y));
+    }
+
+    void setDamageFactor(uint16_t damage_factor)
+    {
+        this->damage_factor = htol16(damage_factor);
+    }
+    uint16_t getDamageFactor() const
+    {
+        return ltoh16(damage_factor);
+    }
+} __attribute__((packed));
 
 class UMesgEndLifeCycleUpdate : public UnitMessage
 {
+private:
+    uint16_t destroyed;
+    uint16_t destroyer;
+
 public:
-    UnitID destroyed;
-    UnitID destroyer;
     unsigned char unit_type;
 
-    inline void set( UnitID &destroyed_unit, UnitID &destroyer_unit, unsigned char unit_type )
+    void set(UnitID destroyed_unit, UnitID destroyer_unit,
+            unsigned char unit_type )
     {
         message_id = _umesg_end_lifecycle;
         message_flags = _umesg_flag_manager_request;
-        destroyed = destroyed_unit;
-        destroyer = destroyer_unit;
+        destroyed = htol16(destroyed_unit);
+        destroyer = htol16(destroyer_unit);
         UMesgEndLifeCycleUpdate::unit_type = unit_type;
     }
+
+    UnitID getDestroyed() const
+    {
+        return ltoh16(destroyed);
+    }
+
+    UnitID getDestroyer() const
+    {
+        return ltoh16(destroyer);
+    }
 }
 __attribute__((packed));
 
@@ -131,12 +205,12 @@ enum { _select_box_allie_visibility,
 class UMesgUpdateSelectBoxInfo : public UnitMessage
 {
 public:
-    unsigned char request_type;
-    bool allie_flag_visiblity;
-    bool flag_visiblity;
-    bool allied_state;
+    uint8_t request_type;
+    uint8_t allie_flag_visiblity;
+    uint8_t flag_visiblity;
+    uint8_t allied_state;
 
-    void set( unsigned char request, bool state_value )
+    void set(unsigned char request, bool state_value)
     {
         message_id = _umesg_update_select_box_info;
         request_type = request;
@@ -161,8 +235,7 @@ __attribute__((packed));
 class UMesgSelfDestruct : public UnitMessage
 {
 public:
-
-    UMesgSelfDestruct( )
+    UMesgSelfDestruct()
     {
         message_id = _umesg_self_destruct;
     }
@@ -173,4 +246,4 @@ __attribute__((packed));
 #pragma()
 #endif
 
-#endif // ** _UNITMESSAGETYPES_HPP
+#endif
