@@ -17,107 +17,51 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <config.h>
 
+#ifdef WIN32
+#include <windows.h>
+#else
+#include <sys/types.h>
+#include <unistd.h>
+#endif
+
+#include <fstream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
 #include <ctype.h>
 #include <signal.h>
 #include <SDL.h>
-#include <SDL_net.h>
 
 #include <optionmm/command_line.hpp>
 
 #include "Util/Log.hpp"
 #include "Util/Exception.hpp"
 #include "Util/FileSystem.hpp"
-#include "MouseInterface.hpp"
-#include "KeyboardInterface.hpp"
-#include "cMouse.hpp"
 
 #include "BaseGameManager.hpp"
 #include "GameConfig.hpp"
 #include "DedicatedGameManager.hpp"
 #include "BotGameManager.hpp"
 #include "PlayerGameManager.hpp"
-#include "IRCLobbyView.hpp"
-
-/** This functions iterates throgh the SDL event queue.
- * It returns true if a quit message has been received, otherwise false.
- */
-bool HandleSDLEvents()
-{
-    static SDL_Event event;
-
-    KeyboardInterface::sampleKeyboard();
-    while(SDL_PollEvent(&event)) {
-        switch (event.type) {
-        case SDL_QUIT:
-            return true;
-            break;
-        case SDL_MOUSEBUTTONDOWN:
-            switch(event.button.button) {
-            case 1:
-                MouseInterface::setLeftButtonDown();
-                cMouse::setButtonMask(LMOUSE_BUTTON_MASK);
-                break;
-            case 3:
-                MouseInterface::setRightButtonDown();
-                cMouse::setButtonMask(RMOUSE_BUTTON_MASK);
-                break;
-            case 2:
-                MouseInterface::setMiddleButtonDown();
-                cMouse::setButtonMask(MMOUSE_BUTTON_MASK);
-                break;
-            }
-            break;
-        case SDL_MOUSEBUTTONUP:
-            switch(event.button.button) {
-            case 1:
-                MouseInterface::setLeftButtonUp();
-                cMouse::clearButtonMask(!LMOUSE_BUTTON_MASK);
-                break;
-            case 3:
-                MouseInterface::setRightButtonUp();
-                cMouse::clearButtonMask(!RMOUSE_BUTTON_MASK);
-                break;
-            case 2:
-                MouseInterface::setMiddleButtonUp();
-                cMouse::clearButtonMask(!MMOUSE_BUTTON_MASK);
-                break;
-            }
-            break;
-        case SDL_KEYDOWN: {
-                KeyboardInterface::keyPressed(event.key.keysym.sym);
-                char c = event.key.keysym.unicode & 0x7F;
-                if (isprint(c)) {
-                    KeyboardInterface::putChar(c);
-                } else {
-                    // it's not a normal char put the 0 into the char buffer to
-                    // indicate extended chars...
-                    KeyboardInterface::putChar(0);
-                    KeyboardInterface::putChar(event.key.keysym.sym);
-                }
-                break;
-            }
-        case SDL_KEYUP:
-            KeyboardInterface::keyReleased(event.key.keysym.sym);
-            break;
-        }
-    }
-
-    return false;
-}
+#include "NetworkGlobals.hpp"
 
 //---------------------------------------------------------------------------
 
+static std::string pidfile;
+
 void shutdown()
 {
-    SDLNet_Quit();
+#ifndef WIN32
+    if(pidfile != "") {
+        unlink(pidfile.c_str());
+    }
+#endif
+    
     SDL_Quit();
     if(gameconfig)
         gameconfig->saveConfig();
     LOGGER.closeLogFile();
-    FileSystem::shutdown();
+    filesystem::shutdown();
 }
 
 #ifndef WIN32
@@ -164,37 +108,52 @@ BaseGameManager *initialise(int argc, char** argv)
     signal(SIGTRAP, signalhandler);
     signal(SIGSYS, signalhandler);
 #endif
+#if !defined(WIN32)
+    signal(SIGPIPE, SIG_IGN);
+#endif
         
     // Parse commandline
     using namespace optionmm;
     command_line commandline(PACKAGE_NAME, PACKAGE_VERSION,
-            "Copyright(c) 1998 Pyrosoft Inc. and others", "", argc, argv);
+            "Copyright(c) 1998 Pyrosoft Inc. and nepanzer-devel team", "",
+            argc, argv);
 
     option<std::string, true, false> connect_option('c', "connect",
-            "directly connect to the specified netpanzer server", "");
+            "Connect to the specified netpanzer server", "");
     commandline.add(&connect_option);
     bool_option dedicated_option('d', "dedicated",
-            "run as dedicated server", false);
+            "Run as dedicated server", false);
     commandline.add(&dedicated_option);
     option<std::string, true, false> bot_option('b', "bot",
-            "connect as bot to specific server", "");
+            "Connect as bot to specific server", "");
     commandline.add(&bot_option);
-    option<int> port_option('p', "port", "run server on specific port", 0);
+    option<int> port_option('p', "port", "Run server on specific port", 0);
     commandline.add(&port_option);
     bool_option debug_option('g', "debug",
-            "enable debug output", false);
+            "Enable debug output", false);
     commandline.add(&debug_option);
-    option<std::string, true, false> lobby_server_option('\0', "lobby_server",
-        "Use 'none' if you dont want to use the lobby", "");
-    commandline.add(&lobby_server_option);
+    option<std::string, true, false> master_server_option('\0', "master_server",
+        "Use 'none' if you dont want to use the master server", "");
+    commandline.add(&master_server_option);
     option<std::string, true, false> game_config_option(0, "game_config",
         "Which config file should be used (only files inside config directory)",
         "");
     commandline.add(&game_config_option);
+    option<bool, false, false> protocol_option('\0', "protocol",
+            "Show version of network protocol", false);
+    commandline.add(&protocol_option);
+    option<std::string, true, false> pidfile_option(0, "pidfile",
+            "Create a pidfile at the specified location", "");
+    commandline.add(&pidfile_option);
 
     if(!commandline.process() || commandline.help() || commandline.version())
         exit(0);
 
+    if(protocol_option.value()) {
+        std::cout << (int) NETPANZER_PROTOCOL_VERSION << std::endl;
+        exit(0);
+    }
+
     if (debug_option.value()) {
         LOGGER.setLogLevel(Logger::LEVEL_DEBUG);
         LOGGER.debug("debug option enabled");
@@ -202,31 +161,48 @@ BaseGameManager *initialise(int argc, char** argv)
         LOGGER.setLogLevel(Logger::LEVEL_INFO);
     }
 
-    // Initialize SDL
-    SDL_Init(SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER);
+    // Initialize SDL (we have to start the video subsystem as well so that
+    // the eventloop is started, otherwise we'll have problems in dedicated
+    // server)
+    if (SDL_Init(SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER) < 0) {
+        fprintf(stderr, "SDL_Init error: %s.\n", SDL_GetError());
+        exit(1);
+    }
     SDL_EnableUNICODE(1);
 
-    // Initialize SDL_net
-    SDLNet_Init();
-
     // Initialize libphysfs
     try {
-        FileSystem::initialize(argv[0], "netpanzer", "netpanzer");
+        filesystem::initialize(argv[0], "netpanzer", "netpanzer");
     } catch(std::exception& e) {
         fprintf(stderr, "%s", e.what());
         shutdown();
         exit(1);
     }
 
-    // try adding the DATADIR
-#ifdef DATADIR
+#ifdef NP_DATADIR
     try {
-	FileSystem::addToSearchPath(DATADIR);
+	filesystem::addToSearchPath(NP_DATADIR);
     } catch(...)
     { }
 #endif
 
-    LOGGER.openLogFile("log.txt");
+    if(dedicated_option.value())
+        LOGGER.openLogFile("log-server.txt");
+    else if(bot_option.value().size() > 0)
+        LOGGER.openLogFile("log-bot.txt");
+    else
+        LOGGER.openLogFile("log.txt");
+
+#ifdef WIN32
+    // SDL redirects stdout and stderr to 2 textfiles, better open a new console
+    // for the dedicated server and the bot
+    if(dedicated_option.value() || bot_option.value().size() > 0) {
+        AllocConsole();
+        freopen("CON", "w", stdout);
+        freopen("CON", "w", stderr);
+        freopen("CON", "r", stdin);
+    }
+#endif
 
     // Initialize random number generator
     srand(time(0));
@@ -237,6 +213,25 @@ BaseGameManager *initialise(int argc, char** argv)
     srand48(time(0));
 #endif
 
+    // create a pidfile
+    pidfile = pidfile_option.value();
+#ifndef WIN32
+    if(pidfile != "") {
+        std::ofstream out(pidfile.c_str());
+        if(!out.good()) {
+            fprintf(stderr, "Couldn't create pidfile '%s'.\n", pidfile.c_str());
+            shutdown();
+            exit(1);
+        }
+        out << getpid() << std::endl;
+        out.close();
+    }
+#else
+    if(pidfile != "") {
+        fprintf(stderr, "Pidfiles not supported on win32.\n");
+    }
+#endif
+    
     BaseGameManager *manager;
     // finally initialize the game objects
     try {
@@ -249,28 +244,29 @@ BaseGameManager *initialise(int argc, char** argv)
             manager = new PlayerGameManager();
         }
 
-        std::string game_config;
-        if(game_config_option.value() != "") {
-            game_config = "/config/";
-            game_config += game_config_option.value();
-        }
-        manager->initialize(game_config);
+        manager->initialize(game_config_option.value());
 
         // gameconfig exists now...
         if(connect_option.value() != "") {
-            gameconfig->serverConnect = connect_option.value();
+            std::string connecthost = connect_option.value();
+            if(connecthost.find("netpanzer://") == 0) {
+                connecthost = connecthost.substr(12, connecthost.size()-12);
+            }
+            gameconfig->serverConnect = connecthost;
             gameconfig->quickConnect = true;
         }                                                               
-        if (lobby_server_option.value().size() > 0) {
-            if (lobby_server_option.value() == "none") {
-                gameconfig->lobbyserver = "";
+        if (master_server_option.value().size() > 0) {
+            if (master_server_option.value() == "none") {
+                gameconfig->masterservers = "";
+            }
+            else {
+                gameconfig->masterservers = master_server_option.value();
             }
-            else { gameconfig->lobbyserver = lobby_server_option.value(); }
         }
         if(port_option.value()) { gameconfig->serverport=port_option.value(); }
 
         return manager;
-    } catch(Exception e) {
+    } catch(std::exception& e) {
         LOGGER.warning("Couldn't initialize the game: %s", e.what());
         shutdown();
         exit(1);
@@ -282,18 +278,12 @@ int netpanzer_main(int argc, char** argv)
 {
     BaseGameManager *manager = initialise(argc, argv);
 
-    // we'll catch every exception here, just to be sure the user gets at least
+    // we'll catch every exception here, to be sure the user gets at least
     // a usefull error message and SDL has a chance to shutdown...
     try {
-        if (manager->launchNetPanzerGame()) {;
-            while(1) {
-                SDL_PumpEvents();
-                if(HandleSDLEvents() == true) {
-                    break;
-                }
-
-                manager->mainLoop();
-            }
+        if (manager->launchNetPanzerGame()) {
+            while(manager->mainLoop())
+                ;
         }
 
         manager->shutdown();
@@ -303,7 +293,7 @@ int netpanzer_main(int argc, char** argv)
     } 
 // in debug mode we want the exception to abort, so that we have the original
 // stack backtrace
-#ifndef DEBUG
+#if !defined(DEBUG) || defined(WIN32)
     catch(std::exception& e) {
         LOGGER.warning("An unexpected exception occured: %s\nShutdown needed.",
                 e.what());
