@@ -27,8 +27,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "System/DummySound.hpp"
 #include "NetworkServerUnix.hpp"
 #include "NetworkClientUnix.hpp"
-
-// ** PObject netPanzer Network Includes
+#include "ConsoleInterface.hpp"
 #include "Server.hpp"
 #include "Client.hpp"
 #include "ClientMessageRouter.hpp"
@@ -38,7 +37,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "NetworkState.hpp"
 #include "SystemNetMessage.hpp"
 #include "ConnectNetMessage.hpp"
-
 #include "Util/Log.hpp"
 #include "Util/Exception.hpp"
 #include "MouseInterface.hpp"
@@ -60,17 +58,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Vehicle.hpp"
 #include "UnitProfileInterface.hpp"
 #include "ObjectiveInterface.hpp"
-#include "ConsoleInterface.hpp"
+#include "Console.hpp"
 #include "UnitGlobals.hpp"
 #include "SelectionBoxSprite.hpp"
-#include "Gdatstct.hpp"
 #include "MapsManager.hpp"
 #include "PowerUpInterface.hpp"
 #include "ChatInterface.hpp"
 #include "Util/Exception.hpp"
 #include "Util/FileSystem.hpp"
 
-// ** GVS Includes
 #include "cMouse.hpp"
 #include "2D/Palette.hpp"
 #include "Desktop.hpp"
@@ -80,7 +76,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "HostView.hpp"
 #include "GetSessionView.hpp"
 #include "GetSessionHostView.hpp"
-#include "WinnerMesgView.hpp"
 #include "RankView.hpp"
 #include "VehicleSelectionView.hpp"
 #include "MiniMapView.hpp"
@@ -108,11 +103,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "MapSelectionView.hpp"
 #include "PlayerNameView.hpp"
 #include "GameInfoView.hpp"
-
-//winsock hack
+#include "BaseGameManager.hpp"
+#include "PlayerGameManager.hpp"
 #include "IPAddressView.hpp"
 
-//** Physics/Particle Stuff
 #include "Particle2D.hpp"
 #include "ParticleSystem2D.hpp"
 #include "ParticleInterface.hpp"
@@ -151,9 +145,9 @@ void GameManager::drawTextCenteredOnScreen(const char *string, PIX color)
 
 // ******************************************************************
 
-void GameManager::loadPalette(char *palette_path)
+void GameManager::loadPalette(const std::string& palette_name)
 {
-    Palette::init(palette_path);
+    Palette::init(palette_name);
     Screen->setPalette(Palette::color);
 }
 
@@ -179,10 +173,9 @@ void GameManager::setVideoMode()
     int mode;
     for(mode=gameconfig->screenresolution; mode>=0; mode--) {
         switch(mode) {
-        case 0: mode_res = iXY(640,480); break;
-        case 1: mode_res = iXY(800,600); break;
-        case 2: mode_res = iXY(1024,768); break;
-        case 3: mode_res = iXY(1280, 1024); break;
+            case 0: mode_res = iXY(640,480); break;
+            case 1: mode_res = iXY(800,600); break;
+            case 2: mode_res = iXY(1024,768); break;
         }
 
         if(Screen->isDisplayModeAvailable(mode_res.x, mode_res.y, 8, flags)) {
@@ -195,14 +188,13 @@ void GameManager::setVideoMode()
 
     Screen->setVideoMode(mode_res.x, mode_res.y, 8, flags);
 
-    WorldViewInterface::setCameraSize( mode_res.x, mode_res.y );
+    WorldViewInterface::setCameraSize( mode_res.x, mode_res.y);
     delete screen;
-    screen = new ScreenSurface(Screen, mode_res.x, mode_res.y, 8);
+    screen = new ScreenSurface(Screen, mode_res.x, mode_res.y);
     gameView.setSize(mode_res);
 
     Desktop::checkResolution(old_res, mode_res);
     Desktop::checkViewPositions(mode_res);
-    //ConsoleInterface::setToSurfaceSize( mode_res );
 
     if(old_res == iXY(0,0)) {
         // users can get annoyed when they see a black screen for half a minute
@@ -222,8 +214,7 @@ void GameManager::setVideoMode()
 // ******************************************************************
 void GameManager::initializeGameLogic()
 {
-    PlayerInterface::initialize( gameconfig->maxplayers,
-                                 gameconfig->initialunits );
+    PlayerInterface::initialize(gameconfig->maxplayers);
     UnitBlackBoard::initializeBlackBoard();
     UnitInterface::initialize( gameconfig->GetUnitsPerPlayer() );
     PathScheduler::initialize();
@@ -256,6 +247,7 @@ void GameManager::shutdownGameLogic()
     PlayerInterface::cleanUp();
     UnitInterface::cleanUp();
     PathScheduler::cleanUp();
+    //ObjectiveInterface::cleanUp();
 }
 
 void GameManager::shutdownParticleSystems()
@@ -307,6 +299,23 @@ void GameManager::finishGameMapLoad()
 
 void GameManager::dedicatedLoadGameMap(const char *map_name )
 {
+    Console::mapSwitch(map_name);
+    *Console::server << "Server Settings:\n"
+        << "Map: " << gameconfig->map << "\n"
+        << "MaxPlayers: " << gameconfig->maxplayers << "\n"
+        << "MaxUnits: " << gameconfig->maxunits << "\n"
+        << "Gametype: " << gameconfig->getGameTypeString() << "\n"
+        << "ObjectivePercentage: " <<
+            gameconfig->objectiveoccupationpercentage << "\n"
+        << "TimeLimit: " << gameconfig->timelimit << "\n"
+        << "FragLimit: " << gameconfig->fraglimit << "\n"
+        << "RespawnType: " << gameconfig->getRespawnTypeString() << "\n"
+        << "Mapcycle: " << gameconfig->mapcycle << "\n"
+        << "Powerups: " << (gameconfig->powerups ? "yes" : "no") << "\n"
+        << "AllowAllies: " << (gameconfig->allowallies ? "yes" : "no") << "\n"
+        << "CloudCoverage: " << gameconfig->cloudcoverage << " (Windspeed "
+           << gameconfig->windspeed << ")" << std::endl;
+    
     map_path = "maps/";
     map_path.append(map_name);
 
@@ -319,17 +328,13 @@ void GameManager::dedicatedLoadGameMap(const char *map_name )
     Particle2D::setCreateParticles(false);
 }
 
-
 // ******************************************************************
-
 void GameManager::spawnPlayer( const PlayerID &player )
 {
-    iXY spawn_point;
-
     sound->stopTankIdle();
 
     // ** Get a new spawn point and spawn the player **
-    MapInterface::getFreeSpawnPoint( &spawn_point );
+    iXY spawn_point = MapInterface::getFreeSpawnPoint();
     PlayerInterface::spawnPlayer( player, spawn_point );
 
     //** Change the location of the view camera to the spawn point **
@@ -338,11 +343,8 @@ void GameManager::spawnPlayer( const PlayerID &player )
     if ( PlayerInterface::getLocalPlayerIndex() == player.getIndex() ) {
         WorldViewInterface::setCameraPosition( world_loc );
     } else {
-        SystemSetPlayerView set_view;
-
-        set_view.camera_loc_x = world_loc.x;
-        set_view.camera_loc_y = world_loc.y;
-        SERVER->sendMessage( player, &set_view, sizeof( SystemSetPlayerView ), 0);
+        SystemSetPlayerView set_view(world_loc.x, world_loc.y);
+        SERVER->sendMessage(player, &set_view, sizeof(SystemSetPlayerView));
     }
 
     sound->playTankIdle();
@@ -372,23 +374,21 @@ void GameManager::spawnPlayer( PlayerState *player_state )
 
 // ******************************************************************
 
-void GameManager::netMessageSetView( NetMessage *message )
+void GameManager::netMessageSetView(const NetMessage* message)
 {
-    SystemSetPlayerView *set_view;
-
-    set_view = (SystemSetPlayerView *) message;
+    const SystemSetPlayerView* set_view
+        = (const SystemSetPlayerView*) message;
 
     WorldViewInterface::setCameraPosition(
-            iXY(set_view->camera_loc_x, set_view->camera_loc_y) );
+            iXY(set_view->getCameraLocX(), set_view->getCameraLocY()) );
 }
 
 // ******************************************************************
 
-void GameManager::netMessageViewControl( NetMessage *message )
+void GameManager::netMessageViewControl(const NetMessage* message)
 {
-    SystemViewControl *view_control;
-
-    view_control =  (SystemViewControl *) message;
+    const SystemViewControl *view_control
+        = (const SystemViewControl*) message;
 
     if ( view_control->action_flags & _view_control_flag_close_all ) {
         Desktop::setVisibilityAllWindows(false);
@@ -405,115 +405,119 @@ void GameManager::netMessageViewControl( NetMessage *message )
 }
 
 // ******************************************************************
-void GameManager::netMessageConnectAlert( NetMessage *message )
+void GameManager::netMessageConnectAlert(const NetMessage* message)
 {
-    SystemConnectAlert *connect_alert = 0;
+    const SystemConnectAlert *connect_alert 
+        = (const SystemConnectAlert*) message;
     PlayerState *player_state = 0;
 
-    connect_alert = (SystemConnectAlert *) message;
+    player_state = PlayerInterface::getPlayerState( connect_alert->getPlayerID() );
 
-    player_state = PlayerInterface::getPlayerState( connect_alert->player_id );
+    switch (connect_alert->alert_enum) {
+        case _connect_alert_mesg_connect:
+            ConsoleInterface::postMessage("%s has joined the game.",
+                    player_state->getName().c_str());
+            break;
 
-    switch( connect_alert->alert_enum ) {
-    case _connect_alert_mesg_connect : {
-            ConsoleInterface::postMessage( "%s has joined the game.",
-                    player_state->getName().c_str() );
-        }
-        break;
+        case _connect_alert_mesg_disconnect: 
+            ConsoleInterface::postMessage("%s has left the game.",
+                    player_state->getName().c_str());
+            break;
 
-    case _connect_alert_mesg_disconnect : {
-            ConsoleInterface::postMessage( "%s has left the game.",
-                    player_state->getName().c_str() );
-        }
-        break;
-
-    case _connect_alert_mesg_client_drop : {
-            ConsoleInterface::postMessage( 
+        case _connect_alert_mesg_client_drop:
+            ConsoleInterface::postMessage(
                     "Connection to %s has been unexpectedly broken.",
-                    player_state->getName().c_str() );
-        }
-        break;
+                    player_state->getName().c_str());
+            break;
 
-    default :
-        assert(0);
-    } // ** switch
+        default:
+            LOGGER.warning("invalid connection_alert enum found.");
+    }
 }
 
 // ******************************************************************
 
-void GameManager::netMessageResetGameLogic( NetMessage *message )
+void GameManager::netMessageResetGameLogic(const NetMessage* )
 {
     resetGameLogic();
 }
 
 // ******************************************************************
 
-void GameManager::getServerGameSetup( NetMessage *message )
+ConnectMesgServerGameSettings* GameManager::getServerGameSetup()
 {
-    ConnectMesgServerGameSettings *game_setup;
+    ConnectMesgServerGameSettings* game_setup 
+        = new ConnectMesgServerGameSettings();
 
-    game_setup = (ConnectMesgServerGameSettings *) message;
-
-    game_setup->max_players = gameconfig->maxplayers;
-    game_setup->max_units = gameconfig->maxunits;
+    game_setup->setMaxPlayers(gameconfig->maxplayers);
+    game_setup->setMaxUnits(gameconfig->maxunits);
     snprintf(game_setup->map_name, 32, gameconfig->map.c_str()); 
-    game_setup->cloud_coverage = gameconfig->cloudcoverage;
-    game_setup->wind_speed = gameconfig->windspeed;
-    game_setup->game_type = gameconfig->gametype;
+    game_setup->setCloudCoverage(gameconfig->cloudcoverage);
+    game_setup->setWindSpeed(gameconfig->windspeed);
+    game_setup->setGameType(gameconfig->gametype);
     game_setup->powerup_state = gameconfig->powerups;
-    game_setup->frag_limit = gameconfig->fraglimit;
-    game_setup->time_limit = gameconfig->timelimit;
-    game_setup->elapsed_time = getGameTime();
+    game_setup->setFragLimit(gameconfig->fraglimit);
+    game_setup->setTimeLimit(gameconfig->timelimit);
+    game_setup->setElapsedTime(getGameTime());
+
+    return game_setup;
 }
 
 // ******************************************************************
 
-void GameManager::netMessagePingRequest( NetMessage *message )
+void GameManager::netMessagePingRequest(const NetMessage* message)
 {
     PlayerID player_id;
-    SystemPingRequest *ping_request;
+    const SystemPingRequest *ping_request
+        = (const SystemPingRequest*) message;
 
-    ping_request = (SystemPingRequest *) message;
-
-    player_id = PlayerInterface::getPlayerID( ping_request->client_player_index );
+    player_id = PlayerInterface::getPlayerID( ping_request->getClientPlayerIndex() );
 
     SystemPingAcknowledge ping_ack;
 
-    if ( (PlayerInterface::getPlayerStatus( player_id ) == _player_state_active) &&
-            (ping_request->client_player_index != 0)
+    if ( (PlayerInterface::getPlayer(player_id.getIndex())->getStatus() == _player_state_active) &&
+            (ping_request->getClientPlayerIndex() != 0)
        ) {
-        SERVER->sendMessage( player_id, &ping_ack, sizeof(SystemPingAcknowledge), 0 );
+        SERVER->sendMessage(player_id, &ping_ack, sizeof(SystemPingAcknowledge));
     }
 }
 
 // ******************************************************************
 
-void GameManager::netMessagePingAcknowledge( NetMessage *message )
+void GameManager::netMessagePingAcknowledge(const NetMessage*)
 {
-    NetworkState::ping_time = (now() - NetworkState::ping_time_stamp) * 1000;
+    //NetworkState::ping_time = (now() - NetworkState::ping_time_stamp) * 1000;
 }
 
 // ******************************************************************
 
-bool GameManager::startClientGameSetup( NetMessage *message, int *result_code )
+bool GameManager::startClientGameSetup(const NetMessage* message, int *result_code)
 {
-    ConnectMesgServerGameSettings *game_setup;
+    const ConnectMesgServerGameSettings* game_setup
+        = (const ConnectMesgServerGameSettings*) message;
 
-    game_setup = (ConnectMesgServerGameSettings *) message;
-
-    gameconfig->maxplayers = game_setup->max_players;
-    gameconfig->maxunits = game_setup->max_units;
-    gameconfig->cloudcoverage = game_setup->cloud_coverage;
-    gameconfig->windspeed = (int) game_setup->wind_speed;
+    gameconfig->maxplayers = game_setup->getMaxPlayers();
+    gameconfig->maxunits = game_setup->getMaxUnits();
+    gameconfig->cloudcoverage = game_setup->getCloudCoverage();
+    gameconfig->windspeed = (int) game_setup->getWindSpeed();
     gameconfig->powerups = game_setup->powerup_state;
-    gameconfig->gametype = game_setup->game_type;
-    gameconfig->fraglimit = game_setup->frag_limit;
-    gameconfig->timelimit = game_setup->time_limit;
+    gameconfig->gametype = game_setup->getGameType();
+    gameconfig->fraglimit = game_setup->getFragLimit();
+    gameconfig->timelimit = game_setup->getTimeLimit();
 
     startGameTimer();
-    game_elapsed_time_offset = game_setup->elapsed_time;
+    game_elapsed_time_offset = game_setup->getElapsedTime();
 
-    startGameMapLoad( game_setup->map_name, 20);
+    try {
+        startGameMapLoad( game_setup->map_name, 20);
+    } catch(std::exception& e) {
+        LOGGER.warning("Error while loading map '%s': %s",
+                game_setup->map_name, e.what());
+        *result_code = _mapload_result_no_map_file;
+        return false;
+    }
+
+    *result_code = _mapload_result_success;
     return true;
 }
 
@@ -530,52 +534,50 @@ bool GameManager::clientGameSetup( int *percent_complete )
 }
 
 // ******************************************************************
-void GameManager::processSystemMessage( NetMessage *message )
+void GameManager::processSystemMessage(const NetMessage* message)
 {
-    switch( message->message_id ) {
-    case _net_message_id_system_set_view :
-        netMessageSetView( message );
-        break;
+    switch(message->message_id) {
+        case _net_message_id_system_set_view:
+            netMessageSetView( message );
+            break;
 
-    case _net_message_id_system_view_control :
-        netMessageViewControl( message );
-        break;
+        case _net_message_id_system_view_control:
+            netMessageViewControl( message );
+            break;
 
-    case _net_message_id_system_reset_game_logic :
-        netMessageResetGameLogic( message );
-        break;
+        case _net_message_id_system_reset_game_logic:
+            netMessageResetGameLogic( message );
+            break;
 
-    case _net_message_id_system_ping_request :
-        netMessagePingRequest( message );
-        break;
+        case _net_message_id_system_ping_request:
+            netMessagePingRequest( message );
+            break;
 
-    case _net_message_id_system_ping_ack :
-        netMessagePingAcknowledge( message );
-        break;
+        case _net_message_id_system_ping_ack:
+            netMessagePingAcknowledge( message );
+            break;
 
-    case _net_message_id_system_connect_alert :
-        netMessageConnectAlert( message );
-        break;
+        case _net_message_id_system_connect_alert:
+            netMessageConnectAlert( message );
+            break;
 
-
-    } // ** switch
+        default:
+            LOGGER.warning("Found unknown SystemNetworkPacket (id %d)",
+                    message->message_id);
+    }
 }
 
 // ******************************************************************
 void GameManager::requestNetworkPing()
 {
-    SystemPingRequest ping_request;
-
-    ping_request.client_player_index = PlayerInterface::getLocalPlayerIndex();
+    SystemPingRequest ping_request(PlayerInterface::getLocalPlayerIndex());
 
     NetworkState::ping_time_stamp = now();
-    CLIENT->sendMessage( &ping_request, sizeof(SystemPingRequest), 0  );
-
+    CLIENT->sendMessage( &ping_request, sizeof(SystemPingRequest));
 }
 
 void GameManager::setNetPanzerGameOptions()
 {
-
     MiniMapInterface::setProperties( gameconfig->getPlayerRadarUnitColor(),
                                      gameconfig->getSelectedRadarUnitColor(),
                                      gameconfig->getAlliedRadarUnitColor(),
@@ -589,12 +591,9 @@ void GameManager::exitNetPanzer()
 {
     quitNetPanzerGame();
 
-    SDL_Event event;
-    event.type = SDL_QUIT;
-    SDL_PushEvent(&event);
+    gamemanager->stopMainLoop();
 }
 
-
 void GameManager::quitNetPanzerGame()
 {
     if ( NetworkState::status == _network_state_client ) {
@@ -603,7 +602,20 @@ void GameManager::quitNetPanzerGame()
     } else {
         ServerConnectDaemon::shutdownConnectDaemon();
         SERVER->closeSession();
+
+        // hacky...
+        PlayerGameManager* playerGameManager 
+            = dynamic_cast<PlayerGameManager*>(gamemanager);
+        if(playerGameManager)
+            playerGameManager->quitGame();
     }
+
+    ParticleSystem2D::removeAll();
+    Particle2D::removeAll();
+    sound->stopTankIdle();
+    UnitInterface::reset();
+    PlayerInterface::reset();
+    ObjectiveInterface::resetLogic();
 }
 
 void GameManager::startGameTimer()
