@@ -22,7 +22,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "PlayerGameManager.hpp"
 
 #include "Server.hpp"
+#include "NetworkServer.hpp"
 #include "Client.hpp"
+#include "NetworkClient.hpp"
 #include "ClientMessageRouter.hpp"
 #include "ClientConnectDaemon.hpp"
 #include "ServerConnectDaemon.hpp"
@@ -53,7 +55,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "ConsoleInterface.hpp"
 #include "UnitGlobals.hpp"
 #include "SelectionBoxSprite.hpp"
-#include "Gdatstct.hpp"
 #include "MapsManager.hpp"
 #include "PowerUpInterface.hpp"
 #include "ChatInterface.hpp"
@@ -69,7 +70,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "HostView.hpp"
 #include "GetSessionView.hpp"
 #include "GetSessionHostView.hpp"
-#include "WinnerMesgView.hpp"
 #include "RankView.hpp"
 #include "VehicleSelectionView.hpp"
 #include "MiniMapView.hpp"
@@ -97,9 +97,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "MapSelectionView.hpp"
 #include "PlayerNameView.hpp"
 #include "GameInfoView.hpp"
+#include "ServerListView.hpp"
 
 #include "IPAddressView.hpp"
-#include "IRCLobbyView.hpp"
 
 //** Physics/Particle Stuff
 #include "Particle2D.hpp"
@@ -113,17 +113,21 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "System/SDLSound.hpp"
 #include "System/SDLVideo.hpp"
 #include "System/DummySound.hpp"
+#include "System/SDLEvents.hpp"
 #include "GameManager.hpp"
 #include "GameControlRulesDaemon.hpp"
 
+#include "InfoThread.hpp"
+#include "HeartbeatThread.hpp"
+
 //** User interface
-#include "UI/Painter.hpp"
+//#include "UI/Painter.hpp"
 
 
 PlayerGameManager::PlayerGameManager()
-    : sdlVideo(0)
+    : sdlVideo(0), heartbeatthread(0), infothread(0)
 {
-    fontManager.loadFont("fixed10", "fonts/fixed10.pcf", 10);
+    //fontManager.loadFont("fixed10", "fonts/fixed10.pcf", 10);
 
     showNewPanel = false;
 }
@@ -155,7 +159,7 @@ void PlayerGameManager::initializeSoundSubSystem()
     try {
         if(gameconfig->enablesound)
             sound = new SDLSound();
-    } catch(Exception e) {
+    } catch(std::exception& e) {
         LOGGER.warning("Couldn't initialize sound: %s", e.what());
     }
 
@@ -178,13 +182,12 @@ void PlayerGameManager::initializeInputDevices()
 //-----------------------------------------------------------------
 void PlayerGameManager::initializeWindowSubSystem()
 {
-    GameManager::loadPalette("wads/netp.act");
+    GameManager::loadPalette("netp");
 
     gameView.init();
     Desktop::add( &gameView );
     Desktop::add(new RankView());
     Desktop::add(new VehicleSelectionView());
-    Desktop::add(new WinnerMesgView());
     Desktop::add( &miniMapView );
     Desktop::add(new CodeStatsView());
     Desktop::add(new LibView());
@@ -199,7 +202,7 @@ void PlayerGameManager::initializeWindowSubSystem()
     progressView->init();
     Desktop::add(progressView);
 
-    GameManager::loadPalette("wads/netpmenu.act");
+    GameManager::loadPalette("netpmenu");
 
     Desktop::add(new MapSelectionView());
     Desktop::add(new MainMenuView());
@@ -223,9 +226,7 @@ void PlayerGameManager::initializeWindowSubSystem()
     Desktop::add(new AreYouSureExitView());
 
     Desktop::add(new IPAddressView());
-    IRCLobbyView *irc_lobby_view=new IRCLobbyView();
-    Desktop::add(irc_lobby_view);
-    irc_lobby_view->setNotifyIRCChangeName((NotifyIRCChangeName *)playernameview);
+    Desktop::add(new ServerListView());
 
     Desktop::setVisibilityAllWindows(false);
     Desktop::setVisibility("MainView", true);
@@ -235,21 +236,25 @@ void PlayerGameManager::initializeWindowSubSystem()
 
 
     //Test for new UI
-    testpanel = new Panels::TestPanel(iXY(30, 60), &fontManager);
-
+    //testpanel = new Panels::TestPanel(iXY(30, 60), &fontManager);
 }
 //-----------------------------------------------------------------
 void PlayerGameManager::inputLoop()
 {
+    if(infothread)
+        infothread->lastFrame = SDL_GetTicks();
+
     processSystemKeys();
 
-    if(showNewPanel && Desktop::getVisible("GameView"))
+#if 0
+    if(showNewPanel && Desktop::getVisible("GameView") && testpanel->contains(mouse.getScreenPos()))
     {
         //Game started, draw interface
         testpanel->processEvents(mouse.getScreenPos(), mouse.getButtonMask(), KMOD_NONE);
-    }
-
-    Desktop::manage(mouse.getScreenPos().x, mouse.getScreenPos().y, mouse.getButtonMask() );
+    }else
+#endif
+       Desktop::manage(mouse.getScreenPos().x,
+               mouse.getScreenPos().y, mouse.getButtonMask());
 
     COMMAND_PROCESSOR.updateScrollStatus( mouse.getScreenPos() );
 }
@@ -260,6 +265,7 @@ void PlayerGameManager::graphicsLoop()
 
     Desktop::draw(*screen);
 
+#if 0
     //TODO : clean this ugly test :)
     if(showNewPanel && Desktop::getVisible("GameView"))
     {
@@ -268,6 +274,7 @@ void PlayerGameManager::graphicsLoop()
         //Game started, draw interface
         testpanel->draw(painter);
     }
+#endif
 
     if (Desktop::getVisible("GameView")) {
         ConsoleInterface::update(*screen);
@@ -294,6 +301,17 @@ void PlayerGameManager::launchMultiPlayerGame()
         joinMultiPlayerGame();
     }
 }
+
+//-----------------------------------------------------------------
+void PlayerGameManager::shutdownNetworkSubSystem()
+{
+    delete infothread;
+    infothread = 0;
+    delete heartbeatthread;
+    heartbeatthread = 0;
+    BaseGameManager::shutdownNetworkSubSystem();
+}
+
 //-----------------------------------------------------------------
 void PlayerGameManager::hostMultiPlayerGame()
 {
@@ -305,6 +323,22 @@ void PlayerGameManager::hostMultiPlayerGame()
     progressView->scrollAndUpdateDirect( "Launching Server ..." );
     try {
         SERVER->hostSession();
+
+        if((bool) gameconfig->publicServer &&
+                (const std::string&) gameconfig->masterservers != "") {
+            try {
+                delete infothread;
+                delete heartbeatthread;
+                infothread = new InfoThread(gameconfig->serverport);
+                heartbeatthread = new HeartbeatThread();
+            } catch(std::exception& e) {
+                LOGGER.warning("heartbeats disabled: %s", e.what());
+                delete infothread;
+                infothread = 0;
+                delete heartbeatthread;
+                heartbeatthread = 0;
+            }
+        }
     } catch(std::exception& e) {
         progressView->scrollAndUpdateDirect( "SERVER LAUNCH FAILED" );
         progressView->scrollAndUpdateDirect(e.what());
@@ -370,7 +404,7 @@ void PlayerGameManager::hostMultiPlayerGame()
     progressView->close();
 
     // Set the palette to the game palette.
-    GameManager::loadPalette( "wads/netp.act" );
+    GameManager::loadPalette( "netp");
 
     GameManager::setNetPanzerGameOptions();
 
@@ -381,6 +415,15 @@ void PlayerGameManager::hostMultiPlayerGame()
     Desktop::setVisibility("GameView", true);
     Desktop::setActiveView("GameView");
 }
+
+void PlayerGameManager::quitGame()
+{
+    delete infothread;
+    infothread = 0;
+    delete heartbeatthread;    
+    heartbeatthread = 0;
+}
+
 //-----------------------------------------------------------------
 void PlayerGameManager::joinMultiPlayerGame()
 {
@@ -394,7 +437,7 @@ void PlayerGameManager::joinMultiPlayerGame()
     sound->playTankIdle();
 }
 
-void PlayerGameManager::mainLoop()
+bool PlayerGameManager::mainLoop()
 {
     // this is a bit ugly...
     static bool firstrun = true;
@@ -407,7 +450,11 @@ void PlayerGameManager::mainLoop()
         }
     }
 
-    BaseGameManager::mainLoop();
+    // handle SDL Events
+    if(handleSDLEvents())
+        return false;
+
+    return BaseGameManager::mainLoop();
 }
 
 //-----------------------------------------------------------------
