@@ -16,6 +16,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <config.h>
+#include <stdexcept>
 #include "PlayerInterface.hpp"
 
 #include "UnitInterface.hpp"
@@ -23,10 +24,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "PlayerNetMessage.hpp"
 #include "Server.hpp"
+#include "NetworkServer.hpp"
 
 #include "ConsoleInterface.hpp"
-
-//#include "WorldViewInterface.hpp"
+// for UNIT_FLAGS_SURFACE
+#include "SelectionBoxSprite.hpp"
 
 // ** PlayerInterface Statics
 PlayerState PlayerInterface::local_player_state;
@@ -36,7 +38,7 @@ unsigned short PlayerInterface::max_players = 0;
 bool *      PlayerInterface::alliance_matrix = 0;
 unsigned short PlayerInterface::local_player_index = 0xFFFF;
 
-NetMessageEncoder PlayerInterface::message_encoder;
+NetMessageEncoder* PlayerInterface::message_encoder = 0;
 unsigned short PlayerInterface::player_sync_index;
 unsigned short PlayerInterface::player_sync_connect_player_index;
 PlayerID PlayerInterface::player_sync_connect_id;
@@ -44,7 +46,9 @@ Timer PlayerInterface::player_sync_timer;
 
 unsigned short PlayerInterface::respawn_rule_player_index = 0;
 
-void PlayerInterface::initialize( unsigned short maxPlayers, unsigned char max_spawn_units )
+SDL_mutex* PlayerInterface::mutex = 0;
+
+void PlayerInterface::initialize(unsigned short maxPlayers)
 {
     char temp_str[64];
     PlayerID player_id;
@@ -56,21 +60,26 @@ void PlayerInterface::initialize( unsigned short maxPlayers, unsigned char max_s
 
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         player_id.setIndex( player_index );
-        player_lists[player_index].setID( player_id );
+        player_lists[player_index].setPlayerID( player_id );
         player_lists[ player_index ].resetStats();
         player_lists[ player_index ].setStatus( _player_state_free );
         player_lists[ player_index ].setFlag( 0 );
-        player_lists[ player_index ].unit_config.initialize( max_spawn_units );
+        player_lists[ player_index ].unit_config.initialize();
         sprintf( temp_str, "Player %lu", player_index );
         player_lists[ player_index ].setName( temp_str );
     }
 
-    local_player_state.setID( PlayerID( 0xFFFF, 0xFFFFFFFF ) );
+    local_player_state.setPlayerID( PlayerID( 0xFFFF, 0xFFFFFFFF ) );
     local_player_state.setStatus( _player_state_allocated );
 
     delete[] alliance_matrix;
     alliance_matrix = new bool [max_players * max_players];
     resetAllianceMatrix();
+
+    mutex = SDL_CreateMutex();
+    if(!mutex) {
+        throw std::runtime_error("Couldn't create PlayerInterface mutex.");
+    }
 }
 
 void PlayerInterface::reset()
@@ -86,45 +95,38 @@ void PlayerInterface::cleanUp()
     delete[] alliance_matrix;
     alliance_matrix = 0;
     max_players = 0;
+
+    SDL_DestroyMutex(mutex);
+    mutex = 0;
 }
 
-void PlayerInterface::setKill( unsigned short by_player_index, unsigned short on_player_index, unsigned short unit_type)
+void PlayerInterface::lock()
 {
-    assert( (by_player_index < max_players) && (on_player_index < max_players) );
-
-    player_lists[ by_player_index ].incKills( unit_type );
-    player_lists[ on_player_index ].incLosses( unit_type );
+    SDL_mutexP(mutex);
 }
 
-void PlayerInterface::setKill( const PlayerID &by_player, const PlayerID &on_player, unsigned short unit_type )
+void PlayerInterface::unLock()
 {
-    assert( (by_player.getIndex() < max_players) && (on_player.getIndex() < max_players) );
-
-    player_lists[ by_player.getIndex() ].incKills( unit_type );
-    player_lists[ on_player.getIndex() ].incLosses( unit_type );
+    SDL_mutexV(mutex);
 }
 
-void PlayerInterface::setKill( const UnitID &by_player, const UnitID &on_player, unsigned short unit_type )
+void PlayerInterface::setKill(PlayerState* by_player, PlayerState* on_player,
+        UnitType unit_type)
 {
-    unsigned short by_player_index;
-    unsigned short on_player_index;
-
-    by_player_index = by_player.getPlayer();
-    on_player_index = on_player.getPlayer();
-
-    assert( (by_player_index < max_players) && (on_player_index < max_players) );
-
-    player_lists[ by_player_index ].incKills(unit_type);
-    player_lists[ on_player_index ].incLosses(unit_type);
+    SDL_mutexP(mutex);
+    by_player->incKills( unit_type );
+    on_player->incLosses( unit_type );
+    SDL_mutexV(mutex);
 }
 
-
 void PlayerInterface::setAlliance( const PlayerID& by_player, const PlayerID& with_player )
 {
     assert( (by_player.getIndex() < max_players) && (with_player.getIndex() < max_players) );
 
+    SDL_mutexP(mutex);
     *(alliance_matrix + (with_player.getIndex() * max_players) + by_player.getIndex() ) = true;
     //*(alliance_matrix + (by_player.getIndex() * max_players) + with_player.getIndex() ) = true;
+    SDL_mutexV(mutex);
 }
 
 
@@ -132,15 +134,19 @@ void PlayerInterface::setAlliance( unsigned short by_player, unsigned short with
 {
     assert( (by_player < max_players) && (with_player < max_players) );
 
+    SDL_mutexP(mutex);
     *(alliance_matrix + (with_player * max_players) + by_player ) = true;
     //*(alliance_matrix + (by_player * max_players) + with_player ) = true;
+    SDL_mutexV(mutex);
 }
 
 void PlayerInterface::clearAlliance( unsigned short by_player, unsigned short with_player )
 {
     assert( (by_player < max_players) && (with_player < max_players) );
 
+    SDL_mutexP(mutex);
     *(alliance_matrix + (with_player * max_players) + by_player ) = false;
+    SDL_mutexV(mutex);
 }
 
 bool PlayerInterface::isAllied( const PlayerID& player, const PlayerID& with_player )
@@ -171,27 +177,33 @@ void PlayerInterface::lockPlayerStats()
 {
     unsigned long player_index;
 
+    SDL_mutexP(mutex);
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         player_lists[ player_index ].lockStats();
     } // ** for
+    SDL_mutexV(mutex);
 }
 
 void PlayerInterface::unlockPlayerStats()
 {
     unsigned long player_index;
 
+    SDL_mutexP(mutex);
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         player_lists[ player_index ].unlockStats();
     } // ** for
+    SDL_mutexV(mutex);
 }
 
 void PlayerInterface::resetPlayerStats()
 {
     unsigned long player_index;
 
+    SDL_mutexP(mutex);
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         player_lists[ player_index ].resetStats();
     } // ** for
+    SDL_mutexV(mutex);
 }
 
 void PlayerInterface::resetAllianceMatrix()
@@ -199,12 +211,13 @@ void PlayerInterface::resetAllianceMatrix()
     unsigned long i;
     unsigned long matrix_size;
 
+    SDL_mutexP(mutex);
     matrix_size = max_players * max_players;
 
     for ( i = 0; i < matrix_size; i++ ) {
         alliance_matrix[ i ] = false;
     }
-
+    SDL_mutexV(mutex);
 }
 
 int PlayerInterface::getActivePlayerCount()
@@ -225,7 +238,9 @@ PlayerState * PlayerInterface::allocateLoopBackPlayer()
 {
     local_player_index = 0;
 
+    SDL_mutexP(mutex);
     player_lists[ local_player_index ].setStatus( _player_state_active );
+    SDL_mutexV(mutex);
 
     return( &player_lists[ local_player_index ] );
 }
@@ -245,15 +260,18 @@ PlayerState * PlayerInterface::allocateNewPlayer()
 {
     unsigned long player_index;
 
+    SDL_mutexP(mutex);
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         if ( player_lists[ player_index ].getStatus() == _player_state_free ) {
             player_lists[ player_index ].setStatus( _player_state_allocated );
             player_lists[ player_index ].resetStats();
 	    player_lists[ player_index ].setColor( player_index );
+            SDL_mutexV(mutex);
             return( &player_lists[ player_index ] );
         } // ** if
 
     } // ** for
+    SDL_mutexV(mutex);
 
     return( 0 );
 }
@@ -274,12 +292,14 @@ void PlayerInterface::spawnPlayer( const PlayerID &player, const iXY &location )
     player_index = player.getIndex();
     assert( player_index < max_players );
 
+    SDL_mutexP(mutex);
     if ( player_lists[ player_index ].getStatus() != _player_state_free ) {
         UnitInterface::spawnPlayerUnits( location,
                                          player,
                                          player_lists[ player_index ].unit_config
                                        );
     } // ** if _player_state_active
+    SDL_mutexV(mutex);
 }
 
 
@@ -305,12 +325,11 @@ bool PlayerInterface::testRuleObjectiveRatio( float precentage, PlayerState ** p
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         if ( ObjectiveInterface::testRuleObjectiveOccupationRatio( player_index, precentage ) == true ) {
             *player_state = &player_lists[ player_index ];
-            return( true );
+            return true;
         } // ** if
-
     } // ** for
 
-    return( false );
+    return false;
 }
 
 
@@ -338,26 +357,23 @@ bool PlayerInterface::testRulePlayerRespawn( bool *completed, PlayerState **play
     return( false );
 }
 
-void PlayerInterface::startPlayerStateSync( const PlayerID &connect_player  )
+void PlayerInterface::startPlayerStateSync(const PlayerID &connect_player)
 {
     player_sync_index = 0;
     player_sync_connect_player_index = connect_player.getIndex();
     player_sync_connect_id = connect_player;
     player_sync_timer.changeRate( 4 );
-    message_encoder.resetEncoder();
+    delete message_encoder;
+    message_encoder = new NetMessageEncoder(connect_player);
 }
 
-bool PlayerInterface::syncPlayerState( int *send_return_code, int *percent_complete )
+bool PlayerInterface::syncPlayerState(int *percent_complete)
 {
     unsigned short player_count = 0;
-    MultiMessage *encode_message;
 
     *percent_complete = -1;
 
-    int send_ret_val;
-    *send_return_code = _network_ok;
-
-
+    SDL_mutexP(mutex);
     if ( player_sync_timer.count() ) {
 
         while( (player_sync_index != max_players) &&
@@ -367,39 +383,22 @@ bool PlayerInterface::syncPlayerState( int *send_return_code, int *percent_compl
                 PlayerStateSync sync_mesg
                     (player_lists[player_sync_index].getNetworkPlayerState());
 
-                while( message_encoder.encodeMessage( &sync_mesg, sizeof(PlayerStateSync), &encode_message ) ) {
-                    send_ret_val = SERVER->sendMessage( player_sync_connect_id,
-                                                        encode_message, encode_message->realSize(),0);
-                    message_encoder.resetEncoder();
-
-                    if ( send_ret_val != _network_ok ) {
-                        *send_return_code = send_ret_val;
-                        return( true );
-                    }
-                } // ** if
-
-            } // ** if
+                message_encoder->encodeMessage(&sync_mesg, sizeof(PlayerStateSync));
+            }
 
             player_sync_index++;
             player_count++;
 
-        } // ** while
+        }
 
-        message_encoder.getEncodeMessage( &encode_message );
-        if ( encode_message != 0 ) {
-            send_ret_val = SERVER->sendMessage(player_sync_connect_id,
-                                               encode_message, encode_message->realSize(), 0);
-
-            if ( send_ret_val != _network_ok ) {
-                *send_return_code = send_ret_val;
-                return( true );
-            }
-
-        } // ** if
+        message_encoder->sendEncodedMessage();
 
         if( (player_sync_index == max_players) ) {
             *percent_complete = 100;
-            return( true );
+            SDL_mutexV(mutex);
+            delete message_encoder;
+            message_encoder = 0;
+            return true;
         } // ** if
 
         float percent;
@@ -407,155 +406,213 @@ bool PlayerInterface::syncPlayerState( int *send_return_code, int *percent_compl
         *percent_complete = (int) percent;
     } // ** if
 
-    return( false );
-
+    SDL_mutexV(mutex);
+    return false;
 }
 
 
-void PlayerInterface::netMessageConnectID( NetMessage *message )
+void PlayerInterface::netMessageConnectID(const NetMessage* message)
 {
-    PlayerConnectID *connect_mesg;
+    const PlayerConnectID *connect_mesg
+        = (const PlayerConnectID *) message;
 
-    connect_mesg = (PlayerConnectID *) message;
-
-    local_player_index = connect_mesg->connect_state.playerindex_id;
+    local_player_index = connect_mesg->connect_state.getPlayerIndex();
 
+    SDL_mutexP(mutex);
     player_lists[local_player_index].setFromNetworkPlayerState
         (&connect_mesg->connect_state);
+    //forceUniquePlayerFlags();
+    SDL_mutexV(mutex);
 }
 
-void PlayerInterface::netMessageSyncState( NetMessage *message )
+void PlayerInterface::netMessageSyncState(const NetMessage* message)
 {
-    PlayerStateSync *sync_mesg;
-    size_t player_index;
-
-    sync_mesg = ( PlayerStateSync *) message;
-    player_index = sync_mesg->player_state.playerindex_id;
+    const PlayerStateSync *sync_mesg
+        = (const PlayerStateSync *) message;
+    uint16_t player_index = sync_mesg->player_state.getPlayerIndex();
+    SDL_mutexP(mutex);
     player_lists[player_index].setFromNetworkPlayerState(&sync_mesg->player_state);
+    forceUniquePlayerFlags();
+    SDL_mutexV(mutex);
 }
 
-void PlayerInterface::netMessageScoreUpdate( NetMessage *message )
+void PlayerInterface::forceUniquePlayerFlags()
 {
-    PlayerScoreUpdate *score_update;
-
-    score_update = (PlayerScoreUpdate *) message;
-
-    setKill( score_update->kill_by_player_index,
-             score_update->kill_on_player_index,
-             score_update->unit_type );
+    // make sure our own flag stays the same (TODO: avoid copy&paste here...)
+    PlayerState& player1 = player_lists[local_player_index];
+    bool unique;
+    do {
+        unique = true;
+        for(int player_id2 = local_player_index-1; player_id2>=0;--player_id2) {
+            const PlayerState& player2 = player_lists[player_id2];
+            if(player1.getFlag() == player2.getFlag()) {
+                unique = false;
+                uint16_t newflag = player1.getFlag() + 1;
+                if(newflag >= UNIT_FLAGS_SURFACE.getFrameCount())
+                    newflag = 0;
+                player1.setFlag(newflag);
+                break;
+            }
+        }
+    } while(!unique);                                                      
+    
+    // make sure each player has a unique flag
+    for(uint16_t player_id = 0; player_id < max_players; ++player_id) {
+        PlayerState& player1 = player_lists[player_id];
+        bool unique;
+        do {
+            unique = true;
+            for(int player_id2 = player_id-1; player_id2>=0;--player_id2) {
+                const PlayerState& player2 = player_lists[player_id2];
+                if(player1.getFlag() == player2.getFlag()) {
+                    unique = false;
+                    uint16_t newflag = player1.getFlag() + 1;
+                    if(newflag >= UNIT_FLAGS_SURFACE.getFrameCount())
+                        newflag = 0;
+                    player1.setFlag(newflag);
+                    break;
+                }
+            }
+        } while(!unique);
+    }
 }
 
-void PlayerInterface::netMessageAllianceRequest( NetMessage *message )
+void PlayerInterface::netMessageScoreUpdate(const NetMessage *message)
+{
+    const PlayerScoreUpdate* score_update 
+        = (const PlayerScoreUpdate *) message;
+
+    PlayerState* player1 = getPlayer(score_update->getKillByPlayerIndex());
+    PlayerState* player2 = getPlayer(score_update->getKillOnPlayerIndex());
+    setKill(player1, player2, (UnitType) score_update->unit_type );
+}
+
+void PlayerInterface::netMessageAllianceRequest(const NetMessage *message)
 {
-    PlayerAllianceRequest *allie_request;
     PlayerState *player_state;
 
-    allie_request = (PlayerAllianceRequest *) message;
+    const PlayerAllianceRequest *allie_request
+        = (const PlayerAllianceRequest *) message;
 
+    SDL_mutexP(mutex);
     if ( allie_request->alliance_request_type == _player_make_alliance ) {
-        setAlliance( allie_request->allie_by_player_index, allie_request->allie_with_player_index );
+        setAlliance(
+                allie_request->getAllieByPlayerIndex(),
+                allie_request->getAllieWithPlayerIndex());
 
-        if( (allie_request->allie_by_player_index == local_player_index) ) {
-            player_state = getPlayerState( allie_request->allie_with_player_index );
+        if( (allie_request->getAllieByPlayerIndex() == local_player_index) ) {
+            player_state = getPlayerState(
+                    allie_request->getAllieWithPlayerIndex());
             ConsoleInterface::postMessage( "Alliance created with %s.",
                     player_state->getName().c_str() );
         } else
-            if( (allie_request->allie_with_player_index == local_player_index) ) {
-                player_state = getPlayerState( allie_request->allie_by_player_index );
+            if( (allie_request->getAllieWithPlayerIndex() == local_player_index) ) {
+                player_state = getPlayerState(
+                        allie_request->getAllieByPlayerIndex());
                 ConsoleInterface::postMessage( "%s has allied with you.",
                         player_state->getName().c_str() );
             }
     } else {
-        clearAlliance( allie_request->allie_by_player_index, allie_request->allie_with_player_index );
+        clearAlliance( allie_request->getAllieByPlayerIndex(),
+                       allie_request->getAllieWithPlayerIndex());
 
-        if( (allie_request->allie_by_player_index == local_player_index) ) {
-            player_state = getPlayerState( allie_request->allie_with_player_index );
+        if( (allie_request->getAllieByPlayerIndex() == local_player_index) ) {
+            player_state = getPlayerState(
+                    allie_request->getAllieWithPlayerIndex());
             ConsoleInterface::postMessage( "Alliance broken with %s.",
                     player_state->getName().c_str() );
         } else
-            if( (allie_request->allie_with_player_index == local_player_index) ) {
-                player_state = getPlayerState( allie_request->allie_by_player_index );
+            if( (allie_request->getAllieWithPlayerIndex()
+                        == local_player_index) ) {
+                player_state = getPlayerState(
+                        allie_request->getAllieByPlayerIndex());
                 ConsoleInterface::postMessage(
                         "%s has broken their alliance with you.",
                         player_state->getName().c_str() );
             }
 
     }
+    SDL_mutexV(mutex);
 
     PlayerAllianceUpdate allie_update;
-
-    allie_update.allie_by_player_index   = allie_request->allie_by_player_index;
-    allie_update.allie_with_player_index = allie_request->allie_with_player_index;
-    allie_update.alliance_update_type = allie_request->alliance_request_type;
-
-    SERVER->sendMessage( &allie_update, sizeof( PlayerAllianceUpdate ), 0 );
+    allie_update.set(allie_request->getAllieByPlayerIndex(),
+                     allie_request->getAllieWithPlayerIndex(),
+                     allie_request->alliance_request_type);
+    SERVER->sendMessage(&allie_update, sizeof(PlayerAllianceUpdate));
 }
 
-void PlayerInterface::netMessageAllianceUpdate( NetMessage *message )
+void PlayerInterface::netMessageAllianceUpdate(const NetMessage* message)
 {
-    PlayerAllianceUpdate *allie_update;
     PlayerState *player_state;
 
-    allie_update = (PlayerAllianceUpdate *) message;
+    const PlayerAllianceUpdate* allie_update
+        = (const PlayerAllianceUpdate *) message;
 
-    if ( allie_update->alliance_update_type == _player_make_alliance ) {
-        setAlliance( allie_update->allie_by_player_index, allie_update->allie_with_player_index );
+    SDL_mutexP(mutex);
+    if (allie_update->alliance_update_type == _player_make_alliance) {
+        setAlliance(
+                allie_update->getAllieByPlayerIndex(),
+                allie_update->getAllieWithPlayerIndex());
 
-        if( (allie_update->allie_by_player_index == local_player_index) ) {
-            player_state = getPlayerState( allie_update->allie_with_player_index );
+        if( (allie_update->getAllieByPlayerIndex() == local_player_index) ) {
+            player_state =
+                getPlayerState(allie_update->getAllieWithPlayerIndex());
             ConsoleInterface::postMessage( "Alliance created with %s.",
                     player_state->getName().c_str() );
         } else
-            if( (allie_update->allie_with_player_index == local_player_index) ) {
-                player_state = getPlayerState( allie_update->allie_by_player_index );
+            if( (allie_update->getAllieWithPlayerIndex() == local_player_index) ) {
+                player_state = getPlayerState(
+                        allie_update->getAllieByPlayerIndex());
                 ConsoleInterface::postMessage( "%s has allied with you.",
                         player_state->getName().c_str() );
             }
     } else {
-        clearAlliance( allie_update->allie_by_player_index, allie_update->allie_with_player_index );
+        clearAlliance(allie_update->getAllieByPlayerIndex(),
+                allie_update->getAllieWithPlayerIndex());
 
-        if( (allie_update->allie_by_player_index == local_player_index) ) {
-            player_state = getPlayerState( allie_update->allie_with_player_index );
+        if( (allie_update->getAllieByPlayerIndex() == local_player_index) ) {
+            player_state = getPlayerState(
+                    allie_update->getAllieWithPlayerIndex());
             ConsoleInterface::postMessage( "Alliance broken with %s.",
                     player_state->getName().c_str() );
         } else
-            if( (allie_update->allie_with_player_index == local_player_index) ) {
-                player_state = getPlayerState( allie_update->allie_by_player_index );
+            if( (allie_update->getAllieWithPlayerIndex() == local_player_index) ) {
+                player_state = getPlayerState(
+                        allie_update->getAllieByPlayerIndex());
                 ConsoleInterface::postMessage(
                         "%s has broken their alliance with you.",
                         player_state->getName().c_str() );
             }
     }
+    SDL_mutexV(mutex);
 }
 
-
-void PlayerInterface::processNetMessage( NetMessage *message )
+void PlayerInterface::processNetMessage(const NetMessage* message)
 {
-    switch( message->message_id ) {
-    case _net_message_id_player_connect_id :
-        netMessageConnectID( message );
-        break;
+    switch(message->message_id) {
+        case _net_message_id_player_connect_id :
+            netMessageConnectID(message);
+            break;
 
-    case _net_message_id_player_sync_state :
-        netMessageSyncState( message );
-        break;
+        case _net_message_id_player_sync_state :
+            netMessageSyncState(message);
+            break;
 
-    case _net_message_id_player_score_update :
-        netMessageScoreUpdate( message );
-        break;
+        case _net_message_id_player_score_update :
+            netMessageScoreUpdate(message);
+            break;
 
-    case _net_message_id_player_alliance_request :
-        netMessageAllianceRequest( message );
-        break;
+        case _net_message_id_player_alliance_request :
+            netMessageAllianceRequest(message);
+            break;
 
-    case _net_message_id_player_alliance_update :
-        netMessageAllianceUpdate( message );
-        break;
-
-    } // ** switch
+        case _net_message_id_player_alliance_update :
+            netMessageAllianceUpdate(message);
+            break;
+    }
 }
 
-void PlayerInterface::disconnectPlayerCleanup( PlayerID &player_id )
+void PlayerInterface::disconnectPlayerCleanup(const PlayerID &player_id )
 {
     PlayerAllianceUpdate allie_update;
 
@@ -564,24 +621,26 @@ void PlayerInterface::disconnectPlayerCleanup( PlayerID &player_id )
 
     disconnect_player_index = player_id.getIndex();
 
+    SDL_mutexP(mutex);
     for ( player_index = 0; player_index < max_players; player_index++ ) {
         if ( isAllied( disconnect_player_index, player_index ) == true ) {
             allie_update.set( disconnect_player_index, player_index, _player_break_alliance );
-            SERVER->sendMessage( &allie_update, sizeof( PlayerAllianceUpdate ), 0 );
+            SERVER->sendMessage(&allie_update, sizeof(PlayerAllianceUpdate));
         }
 
         if ( isAllied( player_index, disconnect_player_index ) == true ) {
             allie_update.set( player_index, disconnect_player_index, _player_break_alliance );
-            SERVER->sendMessage( &allie_update, sizeof( PlayerAllianceUpdate ), 0 );
+            SERVER->sendMessage(&allie_update, sizeof(PlayerAllianceUpdate));
         }
-
-    } // ** for
+    }
 
     player_lists[ disconnect_player_index ].setStatus( _player_state_free );
 
     PlayerState *player_state = getPlayerState( player_id );
 
     PlayerStateSync player_state_update(player_state->getNetworkPlayerState());
+    SDL_mutexV(mutex);
 
-    SERVER->sendMessage( &player_state_update, sizeof( PlayerStateSync ), 0 );
+    SERVER->sendMessage(&player_state_update, sizeof(PlayerStateSync));
 }
+
