@@ -112,6 +112,7 @@ View::~View()
     free(title);
     free(subTitle);
     free(labels);
+    free(searchName);
 } // end ~View::View
 
 // reset
@@ -178,6 +179,7 @@ void View::drawBorder(Surface &viewArea)
 void View::drawButtons(Surface &viewArea)
 {
     assert(this != 0);
+    (void) viewArea;
 
     //pics.setFrame(CLOSE);
     //pics.blt(viewArea, iXY(getSizeX()-pics.getPix().x-borderSize-2, borderSize+2));
@@ -985,11 +987,12 @@ void View::mouseExit(const iXY &pos)
 //---------------------------------------------------------------------------
 void View::scrollBarMove(const iXY &prevPos, const iXY &newPos)
 {
+    (void) prevPos;
+    (void) newPos;
     //if (scrollBar != 0)
     //{
     //	scrollBar->actionPerformed(newPos);
     //}
-
 } // end scrollBarMove
 
 // addLabel
@@ -1045,8 +1048,12 @@ void View::drawLabels(Surface &clientArea)
 
     for (int num = 0; num < numLabels; num++) {
         if (labels[num].isShadowed) {
-            clientArea.bltStringShadowed(labels[num].pos.x, labels[num].pos.y, labels[num].label, labels[num].foreColor, labels[num].backColor);
-        } else clientArea.bltString(labels[num].pos.x, labels[num].pos.y, labels[num].label, labels[num].foreColor);
+            clientArea.bltStringShadowed(iXY(labels[num].pos.x,
+                        labels[num].pos.y),
+                    labels[num].label, labels[num].foreColor,
+                    labels[num].backColor);
+        } else clientArea.bltString(labels[num].pos.x, labels[num].pos.y,
+                labels[num].label, labels[num].foreColor);
     }
 } // end DRAW LABELS
 
@@ -1183,10 +1190,8 @@ void View::addButtonSurfaceSingle(const iXY &pos, Surface &source, const char *t
 //---------------------------------------------------------------------------
 void View::setSearchName(const char *searchName)
 {
-    if (View::searchName != 0) {
-        free(View::searchName);
-        View::searchName = 0;
-    }
+    free(View::searchName);
+    View::searchName = 0;
 
     if (searchName != 0) {
         View::searchName = strdup(searchName);
