@@ -53,6 +53,7 @@ HelpScrollView::HelpScrollView() : SpecialButtonView()
     insert("  LMC + Shift, LMC + Ctrl          Add unit to selection");
     insert("  Ctrl + [0..9]                    Define a group of units");
     insert("  [0..9]                           Recall a group of units");
+    insert("  [0..9] (2 times)                 Center view on a group of units");
     //insert("  'E'                              Select all units on screen");
 
     //insert("  LMC + 'T'............................Track the selected unit");
@@ -66,7 +67,7 @@ HelpScrollView::HelpScrollView() : SpecialButtonView()
     insert("Game Related");
     insert("");
     insert("  LMC + 'A'                        Allies with the clicked unit's team");
-    insert("  ESC                               In game menus");
+    insert("  ESC                              In game menus");
     insert("");
     insert("");
     insert("Outpost Related");
@@ -149,7 +150,7 @@ void HelpScrollView::doDraw(Surface &viewArea, Surface &clientArea)
 
 // drawHelpText
 //--------------------------------------------------------------------------
-void HelpScrollView::drawHelpText(Surface &dest, const int &x, const int &y)
+void HelpScrollView::drawHelpText(Surface &dest, const int &, const int &)
 {
     PIX color   = Color::white;
 
