@@ -403,12 +403,10 @@ void HostOptionsView::addMeterButtons(const iXY &pos)
     add(&choiceWindSpeed);
     xChoiceOffset += minWidth + 10;
 
-    /*
-    checkMapCycle.setLabel("Cycle Maps");
-    checkMapCycle.setState(gameconfig->mapcycling);
-    checkMapCycle.setLocation(2, 125);
-    add(&checkMapCycle);
-    */
+    checkPublic.setLabel("Public");
+    checkPublic.setState(gameconfig->publicServer);
+    checkPublic.setLocation(2, 125);
+    add(&checkPublic);
 
     checkPowerUp.setLabel("PowerUps");
     checkPowerUp.setState(gameconfig->powerups);
@@ -486,7 +484,9 @@ void HostOptionsView::drawMeterInfo(Surface &dest, const iXY &pos)
     if (MapSelectionView::curMap >= 0 && MapSelectionView::mapList.size() > 0) {
         int objectiveCount =
             MapSelectionView::mapList[MapSelectionView::curMap]->objectiveCount;
-        sprintf(strBuf, "%d%% - %d of %d", getObjectiveCapturePercent(), int(float(objectiveCount) * (float(getObjectiveCapturePercent()) / 100.0f)), objectiveCount);
+        sprintf(strBuf, "%d%% - %d of %d", getObjectiveCapturePercent(),
+                int(float(objectiveCount) * (float(getObjectiveCapturePercent()
+                            ) / 100.0f) + 0.999), objectiveCount);
     } else {
         sprintf(strBuf, "Map Data Needed");
     }
@@ -524,12 +524,10 @@ void HostOptionsView::drawMeterInfo(Surface &dest, const iXY &pos)
 //---------------------------------------------------------------------------
 void HostOptionsView::actionPerformed(mMouseEvent me)
 {
-    if (me.getSource(checkMapCycle)) {
-        /*
+    if (me.getSource(checkPublic)) {
         if ( getVisible() ) {
-            gameconfig->mapcycling = checkMapCycle.getState();
+            gameconfig->publicServer = checkPublic.getState();
         }
-        */
     } else if (me.getSource(checkPowerUp)) {
         if ( getVisible() ) {
             gameconfig->powerups = checkPowerUp.getState();
